<?php

use FoodSearch\user_orders as FoodSearch_Orders;
use FoodSearch\Common_Functions;

if (!class_exists('WP_List_Table')) {
    require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class Foodsearch_Orders_Table extends WP_List_Table {

    public $where_status = " where status != 'trash' ";

    public function __construct() {


        parent::__construct(array(
            'singular' => esc_html__('order', 'wp-foodsearch'),
            'plural' => esc_html__('orders', 'wp-foodsearch'),
            'ajax' => false
        ));

        add_action('admin_notices', array($this, 'new_update_notice'));
    }

    public function new_update_notice() {
        return '<div class="notice notice-warning is-dismissible">
             <p>' . esc_html__('this is an example of a notice that appears on the settings page.', 'wp-foodsearch') . '</p>
         </div>';
    }

    protected function get_views() {
        $status = SELF::record_count_fds_status();
        $sts = '';
        if (isset($_REQUEST['status'])) {
            $sts = $_REQUEST['status'];
        }
        $status_links = array(
            "all" => '<a href="?page=fds_orders" class="' . ($sts == '' ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('all', 'wp-foodsearch') . ' <span class="count">(' . $status['total'] . ')</span></a>',
            "completed" => '<a href="?page=fds_orders&status=completed" class="' . ($sts == 'completed' ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('completed', 'wp-foodsearch') . ' <span class="count">(' . $status['completed'] . ')</span></a>',
            "pending" => '<a href="?page=fds_orders&status=pending" class="' . ($sts == 'pending' ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('pending', 'wp-foodsearch') . ' <span class="count">(' . $status['pending'] . ')</span></a>',
            "processing" => '<a href="?page=fds_orders&status=processing" class="' . ($sts == 'processing' ? 'current fds-link' : 'fds-link') . '"  aria-current="page">' . esc_html__('processing', 'wp-foodsearch') . ' <span class="count">(' . $status['processing'] . ')</span></a>',
            "on-hold" => '<a href="?page=fds_orders&status=on-hold" class="' . ($sts == 'on-hold' ? 'current fds-link' : 'fds-link') . '"  aria-current="page">' . esc_html__('on hold', 'wp-foodsearch') . ' <span class="count">(' . $status['hold'] . ')</span></a>',
            "cancelled" => '<a href="?page=fds_orders&status=cancelled" class="' . ($sts == 'cancelled' ? 'current fds-link' : 'fds-link') . '"  aria-current="page">' . esc_html__('cancelled', 'wp-foodsearch') . ' <span class="count">(' . $status['cancelled'] . ')</span></a>',
            "trashed" => '<a href="?page=fds_orders&status=trash" class="' . ($sts == 'trash' ? 'current fds-link' : 'fds-link') . '" aria-current="page">' . esc_html__('trash', 'wp-foodsearch') . ' <span class="count">(' . $status['trash'] . ')</span></a>',
        );
        return $status_links;
    }

    public function record_count_fds_status() {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $sql = "SELECT 
        COUNT(CASE WHEN status='completed' THEN 1 ELSE NULL END) as 'completed',
        COUNT(CASE WHEN status='pending' THEN 1 ELSE NULL END) as 'pending',
        COUNT(CASE WHEN status='processing' THEN 1 ELSE NULL END) as 'processing',
        COUNT(CASE WHEN status='on-hold' THEN 1 ELSE NULL END) as 'hold',
        COUNT(CASE WHEN status='cancelled' THEN 1 ELSE NULL END) as 'cancelled',
        COUNT(CASE WHEN status='trash' THEN 1 ELSE NULL END) as 'trash'
        FROM $wp_track_table";
        $counts = $wpdb->get_row($sql);
        $total = $counts->completed + $counts->pending + $counts->processing + $counts->hold + $counts->trash;
        return array('total' => $total, 'pending' => $counts->pending, 'completed' => $counts->completed, 'processing' => $counts->processing, 'hold' => $counts->hold, 'cancelled' => $counts->cancelled, 'trash' => $counts->trash);
    }

    public function record_count() {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        if (!empty($_REQUEST['status'])) {
            $this->where_status = " where status = '" . $_REQUEST['status'] . "'";
        }

        $wp_track_table = $table_prefix . "$tblname";
        $sql = "select COUNT(order_id) FROM $wp_track_table " . $this->where_status;
        if (isset($_REQUEST['s']) && !empty($_REQUEST['s'])) {
            $sql .= ' and name LIKE "%' . $_REQUEST['s'] . '%"';
        }
        return $wpdb->get_var($sql);
    }

    public function get_records($per_page = 30, $page_number = 1) {
        global $wpdb, $table_prefix;
        $tblname = 'fds_orders';
        if (!empty($_REQUEST['status'])) {
            $this->where_status = " where status = '" . $_REQUEST['status'] . "'";
        }
        $wp_track_table = $table_prefix . "$tblname";
        $sql = "SELECT * from $wp_track_table " . $this->where_status;

        if (isset($_REQUEST['s']) && !empty($_REQUEST['s'])) {
            $sql .= ' and name LIKE "%' . $_REQUEST['s'] . '%"';
        }
        if (!empty($_REQUEST['orderby'])) {
            $sql .= ' ORDER BY ' . esc_sql($_REQUEST['orderby']);
            $sql .= !empty($_REQUEST['order']) ? ' ' . esc_sql($_REQUEST['order']) : ' DESC';
        } else {
            $sql .= ' ORDER BY order_id DESC ';
        }
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ($page_number - 1) * $per_page;

        $result = $wpdb->get_results($sql, 'OBJECT');
        return $result;
    }

    function get_columns() {
        $columns = [
            'cb' => '<input type="checkbox" />',
            'name' => esc_html__('order', 'wp-foodsearch'),
            'date' => esc_html__('date', 'wp-foodsearch'),
            'restaurant_id' => esc_html__('restaurant', 'wp-foodsearch'),
            'status' => esc_html__('status', 'wp-foodsearch'),
            'total' => esc_html__('total', 'wp-foodsearch'),
            'action' => esc_html__('action', 'wp-foodsearch'),
        ];
        return $columns;
    }

    public function get_sortable_columns() {
        $sortable_columns = array(
            'restaurant_id' => array('restaurant_id', true),
            'status' => array('status', true),
        );
        return $sortable_columns;
    }

    public function column_default($item, $column_name) {
        global $foodsearch_user_orders_obj;
        
        $order_id = $item->order_id;
        
        switch ($column_name) {
            case 'name':
                $order_meta = FoodSearch_Orders::get_order_meta($order_id);
                $first_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_first_name');
                $last_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_last_name');
                $title = 'Order #' . $order_id;
                if ($first_name != '' && $last_name != '') {
                    $title .= " ($first_name $last_name)";
                }
                return "<a href='" . add_query_arg(array('order_id' => $order_id)) . "' class='fds-link' data-id='" . $order_id . "' data-title='" . $title . "'>" . $title . "</a><br>";
                break;
            case 'date':
                $create_date = $item->date_created;
                return date_i18n(get_option('date_format'), strtotime($create_date)) . ' ' . date_i18n(get_option('time_format'), strtotime($create_date));
                break;
            case 'restaurant_id':
                $order_meta = FoodSearch_Orders::get_order_meta($order_id);
                $restaurant_id = FoodSearch_Orders::order_meta_value($order_meta, 'restaurant_id');
                if ($restaurant_id > 0) {
                    return "<a href='" . get_edit_post_link($restaurant_id) . "' class='fds-link'>" . get_the_title($restaurant_id) . "</a>";
                } else {
                    return "-";
                }
                break;
            case 'status':
                $status = $item->status;
                $status_label = $foodsearch_user_orders_obj->get_order_status_tclr($status);
                $status_color = $foodsearch_user_orders_obj->get_order_status_tclr($status, 'color');
                $stats_txt_clr = '#fff';
                return "<span class='status-bg' style='background-color:" . $status_color . ";color:" . $stats_txt_clr . ";'>" . $status_label . "</span>";
                break;
            case 'total':
                $total = $item->net_total;
                $total = $total > 0 ? $total : 0;
                return '<strong>' . Common_Functions::get_formatted_price($total, 'fds_order') . '</strong>';
                break;
            case 'action':
                if (empty($_REQUEST['status']) || $_REQUEST['status'] != 'trash') {
                    $actions = "<div class='fds-item-action'>";
                    $actions .= "<a class='menu-edit fds-link' data-id='" . $order_id . "' href='" . add_query_arg(array('order_id' => $order_id)) . "'><i class='dashicons dashicons-edit' aria-hidden='true'></i><span>" . esc_html__('edit', 'wp-foodsearch') . "</span></a>";
                    $actions .= "<a class='menu-trash fds-link' href=?page=fds_orders&action=trash&record=" . $order_id . "><i class='dashicons dashicons-trash' aria-hidden='true'></i><span>" . esc_html__('trash', 'wp-foodsearch') . "</span></a>";
                    $actions .= "</div>";
                } else {
                    $actions = "<div class='fds-item-action'>";
                    $actions .= "<a class='menu-view fds-link' href=?page=fds_orders&action=restore&record=" . $order_id . "&status=trash><i class='dashicons dashicons-visibility' aria-hidden='true'></i><span>" . esc_html__('restore', 'wp-foodsearch') . "</span></a>";
                    $actions .= "</div>";
                }
                return $actions;
                break;
        }
    }

    function column_cb($item) {
        return sprintf('<input type="checkbox" name="bulk-delete[]" value="%s" />', $item->order_id);
    }

    function column_your_name($item) {
        $actions = array(
            'edit' => sprintf('<a href="?page=%s&action=%s&record=%s" class="fds-link">Edit</a>', $_REQUEST['page'], 'edit', $item->order_id),
            'delete' => sprintf('<a href="?page=%s&action=%s&record=%s" class="fds-link">Delete</a>', $_REQUEST['page'], 'delete', $item->order_id),
        );
        return sprintf('%1$s %2$s', $item['name'], $this->row_actions($actions));
    }

    public function get_bulk_actions() {
        $actions = ['bulk-completed' => esc_html__('completed', 'wp-foodsearch'), 'bulk-processing' => esc_html__('processing', 'wp-foodsearch'), 'bulk-hold' => esc_html__('on hold', 'wp-foodsearch'), 'bulk-cancelled' => esc_html__('cancelled', 'wp-foodsearch'), 'bulk-trash' => esc_html__('trash', 'wp-foodsearch'), 'bulk-delete' => esc_html__('delete', 'wp-foodsearch')];
        return $actions;
    }

    public function no_items() {
        esc_html_e('no record found in the database.', 'wp-foodsearch');
    }

    public function restore_record($id) {
        global $wpdb, $table_prefix, $foodsearch_user_orders_obj;
        
        $set_status = $foodsearch_user_orders_obj->order_get_last_status($id);
        
        $tblname = 'fds_orders';
        $wp_track_table = $table_prefix . "$tblname";
        $data = array('status' => $set_status);
        $where = array('order_id' => $id);
        $wpdb->update($wp_track_table, $data, $where);
    }

    public function process_bulk_action() {
        global $foodsearch_user_orders_obj;
        
        if ('delete' === $this->current_action()) {
            $foodsearch_user_orders_obj->delete_record(absint($_GET['record']));
        } else if ('trash' === $this->current_action()) {
            $foodsearch_user_orders_obj->trash_record(absint($_GET['record']));
        } else if ('restore' === $this->current_action()) {
            self::restore_record(absint($_GET['record']));
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-delete' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-delete' )) {
            $delete_ids = esc_sql($_POST['bulk-delete']);
            foreach ($delete_ids as $id) {
                $foodsearch_user_orders_obj->delete_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-trash' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-trash' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                $foodsearch_user_orders_obj->trash_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-cancelled' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-cancelled' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                $foodsearch_user_orders_obj->cancelled_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-pending' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-pending' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                $foodsearch_user_orders_obj->pending_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-processing' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-processing' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                $foodsearch_user_orders_obj->processing_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-hold' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-hold' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                $foodsearch_user_orders_obj->on_hold_record($id);
            }
        } else if (( isset($_POST['action']) && $_POST['action'] == 'bulk-completed' ) || ( isset($_POST['action2']) && $_POST['action2'] == 'bulk-completed' )) {
            $trash_ids = esc_sql($_POST['bulk-delete']);
            foreach ($trash_ids as $id) {
                $foodsearch_user_orders_obj->completed_record($id);
            }
        }
    }

    public function get_hidden_columns() {
        return array();
    }

    public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = $this->get_hidden_columns();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();
        $per_page = $this->get_items_per_page('records_per_page', 30);
        $current_page = $this->get_pagenum();
        $total_items = self::record_count();
        $data = self::get_records($per_page, $current_page);
        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page' => $per_page,
        ]);
        $this->items = $data;
    }

}
