<?php

namespace FoodSearch\Dashboard\Restaurant;

use FoodSearch\Common_Functions;

class Image_Upload {

    public function __construct() {

        add_filter('foodsearch_restaurant_dash_logo_cover_html', [$this, 'content'], 10, 4);
    }

    public function content($html, $menu_data, $section_key, $element_key) {

        $element_data = $menu_data['sections'][$section_key]['elements'][$element_key];
        
        $common_functions = new Common_Functions;

        $user_id = get_current_user_id();

        $restaurant_id = Common_Functions::user_restaurant_id($user_id);
        $restaurant_post = get_post($restaurant_id);

        ob_start();
        $upload_photo_switch = isset($element_data['photo']) ? $element_data['photo'] : 'on';
        if ($upload_photo_switch == 'on') {

            wp_enqueue_style('foodsearch-croppie');
            wp_enqueue_script('foodsearch-croppie');
            
            $pic_pixel_size = isset($element_data['pic_size']) ? $element_data['pic_size'] : '200';
            $pic_file_size = isset($element_data['pic_file_size']) ? $element_data['pic_file_size'] : '5120';
            
            //
            $cover_file_size = isset($element_data['cover_file_size']) ? $element_data['cover_file_size'] : '5120';
            
            $file_sizes_arr = array(
                '300' => esc_html__('300kb', 'wp-foodsearch'),
                '500' => esc_html__('500kb', 'wp-foodsearch'),
                '750' => esc_html__('750kb', 'wp-foodsearch'),
                '1024' => esc_html__('1mb', 'wp-foodsearch'),
                '2048' => esc_html__('2mb', 'wp-foodsearch'),
                '3072' => esc_html__('3mb', 'wp-foodsearch'),
                '4096' => esc_html__('4mb', 'wp-foodsearch'),
                '5120' => esc_html__('5mb', 'wp-foodsearch'),
                '10120' => esc_html__('10mb', 'wp-foodsearch'),
                '50120' => esc_html__('50mb', 'wp-foodsearch'),
                '100120' => esc_html__('100mb', 'wp-foodsearch'),
                '200120' => esc_html__('200mb', 'wp-foodsearch'),
                '300120' => esc_html__('300mb', 'wp-foodsearch'),
                '500120' => esc_html__('500mb', 'wp-foodsearch'),
                '1000120' => esc_html__('1gb', 'wp-foodsearch'),
            );

            $file_size_str = $cover_size_str = esc_html__('5mb', 'wp-foodsearch');
            if (isset($file_sizes_arr[$pic_file_size])) {
                $file_size_str = $file_sizes_arr[$pic_file_size];
            }
            if (isset($file_sizes_arr[$cover_file_size])) {
                $cover_size_str = $file_sizes_arr[$cover_file_size];
            }
            
            $figure_rand = rand(100000, 999999);
            $pic_title = isset($restaurant_post->post_title) ? $restaurant_post->post_title : '';

            $is_img_uploded = false;
            $img_thumb_id = get_post_thumbnail_id($restaurant_id);
            if ($img_thumb_id > 0) {
                $is_img_uploded = true;
            }

            $logo_url = foodsearch_restaurant_logo_url($user_id, $restaurant_id);
            
            $cover_photo_attchid = get_post_meta($restaurant_id, 'foodsearch_restaurant_banner', true);
            $cover_photo_image = wp_get_attachment_image_src($cover_photo_attchid, 'full');
            $cover_photo_url = isset($cover_photo_image[0]) && esc_url($cover_photo_image[0]) != '' ? $cover_photo_image[0] : '';
            ?>
            <div class="fds-dashboard-user-account-box">
                <div class="fds-dashboard-upload-section fds-restaurant-dash-uploadlogo">
                    <div id="upload-coverimg-<?php echo ($figure_rand) ?>" class="fds-dashboard-upload-thumb" data-fid="<?php echo ($cover_file_size) ?>" data-sizerr="<?php printf(esc_html__('maximum file size allowed is %s.', 'wp-foodsearch'), $cover_size_str) ?>" data-typerr="<?php esc_html_e('only correct format images are allowed to upload.', 'wp-foodsearch') ?>">
                        <div class="fds-coverimg-holder"<?php echo ($cover_photo_url != '' ? ' style="background-image: url(' . $cover_photo_url . ')"' : '') ?>></div>
                        <div class="fds-dashboard-file-upload">
                            <label for="upload-restaurant-cover-<?php echo ($figure_rand) ?>" class="fds-upload-btn2 fds-input-label"><i class="fds-icon fds-camera"></i> <?php esc_html_e('upload cover photo', 'wp-foodsearch') ?></label>
                            <input id="upload-restaurant-cover-<?php echo ($figure_rand) ?>" class="fds-file-upload-input2 fds-update-anything-action" type="file" name="fds_upload_cover" data-id="<?php echo ($figure_rand) ?>" data-nid="<?php echo ($user_id) ?>">
                            <div class="fds-loader-holder" style="display: none;"></div>
                        </div>
                    </div>
                    <div id="upload-pic-<?php echo ($figure_rand) ?>" class="fds-dashboard-account-upload" data-pid="<?php echo ($pic_pixel_size) ?>" data-fid="<?php echo ($pic_file_size) ?>" data-sizerr="<?php printf(esc_html__('maximum file size allowed is %s.', 'wp-foodsearch'), $file_size_str) ?>" data-typerr="<?php esc_html_e('only correct format images are allowed to upload.', 'wp-foodsearch') ?>">
                        <div class="fds-proile-savedimg-con fds-dashboard-account-upload-thumb">
                            <a href="javascript:void(0);" class="remove-user-img fds-update-anything-action fds-link" data-id="<?php echo ($figure_rand) ?>" data-nid="<?php echo ($user_id) ?>"<?php echo ($is_img_uploded ? '' : ' style="display:none;"') ?>><i class="fds-icon fds-time-simple"></i></a>
                            <img src="<?php echo ($logo_url) ?>" alt="<?php echo ($pic_title) ?>">
                        </div>
                        <div class="fds-imgcropper-mainbox" style="display: none; max-width: <?php echo (absint($pic_pixel_size) + 50) ?>px;">
                            <div id="fds-imgcropper-box" class="fds-imgcropper-holder"></div>
                            <span class="fds-dragslidr-txt"><?php esc_html_e('drag and zoom to resize image.', 'wp-foodsearch') ?></span>
                            <div class="fds-imgcrop-btncon fds-btn fds-small-btn"><a href="#" class="fds-link fds-has-bg fds-cropimg-uploadbtn" data-id="<?php echo ($figure_rand) ?>" data-nid="<?php echo ($user_id) ?>"><?php esc_html_e('save image', 'wp-foodsearch') ?></a></div>
                        </div>
                        <div class="fds-profile-upload-cnt">
                            <span class="fds-dashboard-account-upload-title"><?php echo ($pic_title) ?></span>
                            <small><?php esc_html_e('update to your restaurant logo', 'wp-foodsearch') ?></small>
                            <div class="fds-dashboard-file-upload2">
                                <label for="upload-restaurant-logo-<?php echo ($figure_rand) ?>" class="fds-upload-btn2 fds-input-label"><?php esc_html_e('upload logo', 'wp-foodsearch') ?></label>
                                <input id="upload-restaurant-logo-<?php echo ($figure_rand) ?>" class="fds-file-upload-input2 fds-update-anything-action" type="file" name="fds_upload_logo" data-id="<?php echo ($figure_rand) ?>" data-nid="<?php echo ($user_id) ?>">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
        $html = ob_get_clean();

        return $html;
    }

}

new Image_Upload;
