<?php

namespace FoodSearch\Dashboard\Restaurant;
use FoodSearch\Common_Functions;

class Menu_Builder {
    
    public function __construct() {
        
        add_action('wp_enqueue_scripts', [$this, 'style_scripts']);
        add_action('wp_print_styles', [$this, 'front_priority_styles'], 998);
        
        add_filter('foodsearch_restaurant_dash_menu_builder_html', [$this, 'content'], 10, 4);
    }
    
    public function front_priority_styles() {
        
        wp_enqueue_style('menu-builder-style', foodsearch_plugin_get_url('assets/scss/build/css/menu-builder.css'), false);
    }
    
    public function style_scripts() {
        wp_enqueue_style('dashicons');
        
        wp_register_script('menu_builder_front', foodsearch_plugin_get_url('assets/js/menu_builder_front.js'), array('jquery'));
        $localize_strings = array(
            'site_url' =>  esc_url_raw( rest_url() ),
            'wpnonce' => wp_create_nonce('wp_rest'),            
            'adminCheck' => (is_admin()?'true':'false'),
        );
        wp_localize_script('menu_builder_front', 'menubuilder_front_strings', $localize_strings);
        
        wp_register_script('menu_builder_script', foodsearch_plugin_get_url('assets/js/menu_builder_script.js'), array('jquery'));

        $empty_menus_con = '<div class="fds-no-menuitm">' . esc_html__('add menu items here.', 'wp-foodsearch') . '</div>';
        $localize_strings = array(
            'site_url' =>  esc_url_raw( rest_url() ),
            'wpnonce' => wp_create_nonce('wp_rest'),            
            'adminCheck' => (is_admin()?'true':'false'),
            'url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('ajax-nonce'),
            'go_back' => esc_html__('go back', 'wp-foodsearch'),
            'nutri_info_txt' => esc_html__('nutritional information', 'wp-foodsearch'),
            'item_price_txt' => esc_html__('item price', 'wp-foodsearch'),
            'add_menuitm_txt' => esc_html__('add menu item', 'wp-foodsearch'),
            'type_menucat_name' => esc_html__('type menu category name', 'wp-foodsearch'),
            'empty_menus_htmltxt' => $empty_menus_con,
            'delete_conf_msg' => esc_html__('do you realy want to delete it?', 'wp-foodsearch'),
        );
        wp_localize_script('menu_builder_script', 'menu_builder_strings', $localize_strings);
    }
    
    public function content($html, $menu_data, $section_key, $element_key) {
        
        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_script('jquery-ui-widget');
        wp_enqueue_script('jquery-ui-mouse');
        wp_enqueue_script('jquery-ui-accordion');
        wp_enqueue_script('jquery-ui-autocomplete');
        wp_enqueue_script('jquery-ui-slider');
        
        wp_enqueue_script('menu_builder_front');
        wp_enqueue_script('menu_builder_script');
        
        $user_id = get_current_user_id();
        $user_obj = get_user_by('id', $user_id);
        
        $common_functions = new Common_Functions;
        
        $element_data = $menu_data['sections'][$section_key]['elements'][$element_key];
        $element_label = isset($element_data['label']) ? $element_data['label'] : '';
        if ($element_label == '') {
            $element_label = esc_html__('menu builder', 'wp-foodsearch');
        }

        $restaurant_id = Common_Functions::user_restaurant_id($user_id);

        $get_menu_id = isset($_GET['menu_id']) ? $_GET['menu_id'] : '';
        $foodsearch_menu_builder_object = \MenuBuilder::instance();

        ob_start();
        if ($get_menu_id > 0) {
            $menu_title = $foodsearch_menu_builder_object->menu_title_by_id($get_menu_id)
            ?>
            <strong>: <?php echo ($menu_title) ?></strong> <div class="fds-btn fds-small-btn"><a href="javascript:void(0);" class="fds-has-bg fds-link"><?php esc_html_e('go back', 'wp-foodsearch'); ?></a></div>
            <?php
        }
        $menu_title_html = ob_get_clean();

        ob_start();
        ?>
        <div class="fds-heading-title" id="menuListBox">
            <strong class="fds-locs-hding"><?php echo ($element_label) ?> <span class="fds-selected-menu-title"><?php echo ($menu_title_html) ?></span></strong>
        </div>
        <div class="fds-resturant-menubildr-wrap-box" data-view="dash" data-tab="<?php echo get_query_var('tab') ?>" data-id="<?php echo ($restaurant_id) ?>">
            <div class="fds-menus-grid"<?php echo ($get_menu_id > 0 ? ' style="display: none;"' : '') ?>>

                <?php
                $have_menus = false;
                $menus = $this->restaurant_menus($restaurant_id);
                if (!empty($menus) && sizeof($menus) > 0) {
                    $have_menus = true;
                }

                $foodsearch_menu_builder_object->menu_grid_boxes($menus);
                ?>
            </div>

            <div id="menuDetailsID"<?php echo ($get_menu_id > 0 ? '' : ' style="display: none;"') ?>>
                <?php
                if ($get_menu_id > 0) {
                    $menu_content = $foodsearch_menu_builder_object->menu_items_bywhere_id($get_menu_id, $user_id);
                    echo ($menu_content);
                }
                ?>
            </div>

            <div class="fds-addmenu-mainbtnsec"<?php echo ($get_menu_id > 0 ? ' style="display: none;"' : '') ?>>
                <div id="fds-emptymenu-btnsec" class="fds-menu-builder-empty empty-menus-btncon"<?php echo ($have_menus ? ' style="display:none;"' : '') ?>>
                    <i class="fds-menu-builder-empty-icon fds-icon fds-menu-one"></i>
                    <div class="fds-menu-builder-empty-dec"><p><?php esc_html_e('you have blank food menu start adding content or select menu from templates', 'wp-foodsearch') ?></p></div>
                    <div class="fds-btn fds-medium-btn">
                        <a href="javascript:void(0);" class="fds-addmenu-inlist fds-has-bg fds-link" data-bplc="" data-id="<?php echo ($restaurant_id) ?>"><i class="fds-icon fds-writing"></i> <?php esc_html_e('add new menu', 'wp-foodsearch') ?></a>
                        <a href="javascript:void(0);" class="sec-color fds-has-save fds-link"><i class="fds-icon fds-writing"></i> <?php esc_html_e('import from templates', 'wp-foodsearch') ?></a>
                    </div>
                </div>
                <div id="fds-havemenu-btnsec" class="fds-menu-builder-empty have-menus-btncon"<?php echo ($have_menus ? '' : ' style="display:none;"') ?>>
                    <div class="fds-btn fds-medium-btn">
                        <a href="javascript:void(0);" class="fds-addmenu-inlist fds-has-bg fds-link" data-bplc="" data-id="<?php echo ($restaurant_id) ?>"><i class="fds-icon fds-writing"></i> <?php esc_html_e('add new menu', 'wp-foodsearch') ?></a>
                    </div>
                </div>
            </div>
        </div>
        <?php
        $html = ob_get_clean();
        
        add_action('wp_footer', function() {
            ?>
            <div id="fds-menuitem-mpopup" class="fds-modal-popup fds-popup-hide fds-menuitem-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div id="menuitms-templates-popup" class="fds-modal-popup fds-popup-hide fds-menu-templates-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }, 20);
        
        return $html;
    }
    
    public function restaurant_menus($restaurant_id) {
        global $table_prefix, $wpdb;
        $table_name = $table_prefix . 'menus';
        $results = $wpdb->get_results("SELECT * FROM $table_name WHERE restaurant_id={$restaurant_id} order by id desc");
        if (empty($results)) { // Checking if $results have some values or not
            $results = array();
        }

        return $results;
    }

}

new Menu_Builder;
