<?php

namespace FoodSearch;
use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

class Google_Maps {

    public function __construct() {
        
        add_action('wp_enqueue_scripts', array($this, 'maps_enqueue'), 5);
        add_action('admin_enqueue_scripts', array($this, 'maps_enqueue'), 5);
    }
    
    public function maps_enqueue() {
        global $foodsearch_plugin_settings;
        
        $default_country = isset($foodsearch_plugin_settings['location_settings']['default_country']) ? $foodsearch_plugin_settings['location_settings']['default_country'] : '';
        
        $countries_json = '';
        if (!empty($default_country) && is_array($default_country)) {
            $countries_json = json_encode($default_country);
        } else if (!empty($default_country)) {
            $countries_json = json_encode(array($default_country));
        }

        $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';

        $google_api_key = isset($foodsearch_plugin_settings['api_settings']['google_api']) ? $foodsearch_plugin_settings['api_settings']['google_api'] : '';
        $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
        
        if ($location_maps == 'on' && $map_type == 'google') {
            
            $locations_obj = new User_Locations;
            
            $def_latlng = $locations_obj->get_default_latlng();

            $default_lat_val = $def_latlng[0];
            $default_lng_val = $def_latlng[1];
            
            if ($google_api_key != '') {
                wp_register_script('foodsearch-google-map', 'https://maps.googleapis.com/maps/api/js?key=' . $google_api_key . '&libraries=places', array(), \FoodSearch_Plugin::get_version(), true);
            } else {
                wp_register_script('foodsearch-google-map', 'https://maps.googleapis.com/maps/api/js?libraries=places', array(), \FoodSearch_Plugin::get_version(), true);
            }
            wp_register_script('foodsearch-googlemaps-js', foodsearch_plugin_get_url('assets/js/google-maps.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
            $localize_arr = array(
                'api_key' => $google_api_key,
                'mapbox_access_token' => $mapbox_api_key,
                'def_countries' => $countries_json,
                'lat' => $default_lat_val,
                'lng' => $default_lng_val,
                'zoom' => ($map_zoom > 0 ? $map_zoom : 6),
            );
            wp_localize_script('foodsearch-googlemaps-js', 'google_map_vars', $localize_arr);
        }
    }
    
    public function dash_loc_map($user_id) {
        global $foodsearch_plugin_settings;

        $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        
        if ($location_maps == 'on' && $map_type == 'google') {
            wp_enqueue_script('foodsearch-google-map');
            wp_enqueue_script('foodsearch-googlemaps-js');
            
            $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';
            $map_zoom = $map_zoom > 0 ? $map_zoom : 6;
            
            $map_height = '300px';
            $map_width = '100%';
            
            $rand_num = rand(100000, 999999);
            ?>
            <div class="fds-location-full-map fds-location-map-outer" data-id="<?php echo absint($rand_num); ?>">
                <input type="hidden" name="fds_location_map_zoom" class="fds-map-zoom-field" value="<?php echo ($map_zoom) ?>">
                <div id="fds-map-<?php echo absint($rand_num); ?>" style="width: <?php echo ($map_width) ?>; height: <?php echo ($map_height) ?>;"></div>
            </div>
            <?php
        }
    }

}

new Google_Maps();

