<?php

namespace FoodSearch;
use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

class MapBox {

    public function __construct() {

        add_action('wp_enqueue_scripts', array($this, 'maps_enqueue'), 5);
        add_action('admin_enqueue_scripts', array($this, 'maps_enqueue'), 5);
    }
    
    public function maps_enqueue() {
        global $foodsearch_plugin_settings;
        
        $default_country = isset($foodsearch_plugin_settings['location_settings']['default_country']) ? $foodsearch_plugin_settings['location_settings']['default_country'] : '';
        
        $countries_json = '';
        if (!empty($default_country) && is_array($default_country)) {
            $countries_json = json_encode($default_country);
        } else if (!empty($default_country)) {
            $countries_json = json_encode(array($default_country));
        }

        $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';

        $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
        if ($location_maps == 'on' && $map_type == 'mapbox' && $mapbox_api_key != '') {

            $mapbox_style = isset($foodsearch_plugin_settings['location_settings']['mapbox_style']) ? $foodsearch_plugin_settings['location_settings']['mapbox_style'] : '';
            
            $locations_obj = new User_Locations;
            
            $def_latlng = $locations_obj->get_default_latlng();
            
            $default_lat_val = $def_latlng[0];
            $default_lng_val = $def_latlng[1];

            wp_register_style('foodsearch-mapbox', foodsearch_plugin_get_url('assets/scss/build/css/mapbox-gl.css'), array(), \FoodSearch_Plugin::get_version());
            wp_register_script('foodsearch-mapbox', 'https://api.mapbox.com/mapbox-gl-js/v2.6.1/mapbox-gl.js', array(), \FoodSearch_Plugin::get_version(), true);
            wp_register_script('foodsearch-mapbox-geocode', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.7.2/mapbox-gl-geocoder.min.js', array(), \FoodSearch_Plugin::get_version(), true);
            wp_register_style('foodsearch-mapbox-geocode', foodsearch_plugin_get_url('assets/scss/build/css/mapbox-gl-geocoder.css'), array(), \FoodSearch_Plugin::get_version());
            wp_register_script('foodsearch-mapbox-js', foodsearch_plugin_get_url('assets/js/mapbox.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);

            $localize_arr = array(
                'api_key' => $mapbox_api_key,
                'map_style' => $mapbox_style,
                'def_countries' => $countries_json,
                'lat' => $default_lat_val,
                'lng' => $default_lng_val,
                'zoom' => ($map_zoom > 0 ? $map_zoom : 6),
                'search_placeholder' => esc_html__('search location', 'wp-foodsearch'),
            );
            wp_localize_script('foodsearch-mapbox-js', 'mapbox_loc_vars', $localize_arr);
        }
    }
    
    public function dash_loc_map($user_id) {
        global $foodsearch_plugin_settings;

        $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        
        if ($location_maps == 'on' && $map_type == 'mapbox') {
            wp_enqueue_style('foodsearch-mapbox');
            wp_enqueue_script('foodsearch-mapbox');
            wp_enqueue_script('foodsearch-mapbox-geocode');
            wp_enqueue_style('foodsearch-mapbox-geocode');
            wp_enqueue_script('foodsearch-mapbox-js');
            
            $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';
            $map_zoom = $map_zoom > 0 ? $map_zoom : 6;
            
            $map_height = '300px';
            $map_width = '100%';
            
            $rand_num = rand(100000, 999999);
            ?>
            <div class="fds-location-full-map fds-location-map-outer" data-id="<?php echo absint($rand_num); ?>">
                <input type="hidden" name="fds_location_map_zoom" class="fds-map-zoom-field" value="<?php echo ($map_zoom) ?>">
                <div id="fds-map-<?php echo absint($rand_num); ?>" style="width: <?php echo ($map_width) ?>; height: <?php echo ($map_height) ?>;"></div>
            </div>
            <?php
        }
    }

}

new MapBox();

