<?php

namespace FoodSearch;

use FoodSearch\Common_Functions;

class Restaurant_Menu_Templates {
    
    public function __construct() {
        add_action('admin_menu', array($this, 'admin_page'));
    }

    public static function export_menu_item_template($menu_id, $restaurant_id, $export_outside = false) {
        if ($menu_id > 0) {
            $where = ' where menu_id =' . $menu_id;

            global $table_prefix, $wpdb, $foodsearch_upload_files_extpath, $foodsearch_upload_subdir_extpath;
            
            $foodsearch_upload_files_extpath = 'templates';
            $foodsearch_upload_subdir_extpath = 'restaurant';
            
            $table_name = $table_prefix . 'menu_items';
            $sql = "SELECT * FROM $table_name$where ORDER BY id ASC";
            $results = $wpdb->get_results($sql);
            if (!empty($results)) {
                
                $rand_id = rand(1000000, 9999999);
                $current_time = current_time('timestamp');
                
                $menu_name = esc_html__('menu template', 'wp-foodsearch');
                $table_name = $table_prefix . 'menus';
                $sql = "SELECT name FROM $table_name WHERE id={$menu_id}";
                $menu_result = $wpdb->get_col($sql);
                if (isset($menu_result[0])) {
                    $menu_name = sprintf(esc_html__('%s template', 'wp-foodsearch'), $menu_result[0]);
                }
                
                // Restaurant Nutritions Data
                $restaurant_nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);
                
                require_once(ABSPATH . 'wp-admin/includes/file.php');
                WP_Filesystem();
                global $wp_filesystem;

                if (!$export_outside) {
                    add_filter('upload_dir', 'foodsearch_public_upload_files_path');
                    $wp_upload_dir = wp_upload_dir();
                    $template_files_dir = $wp_upload_dir['path'] . '/restaurant-menu-templates';

                    if (!is_dir($template_files_dir)) {
                        wp_mkdir_p($template_files_dir);
                    }
                    $htaccs_file = $template_files_dir . '/.htaccess';
                    if (!file_exists($htaccs_file)) {
                        $file_contnt = 'deny from all';
                        $wp_filesystem->put_contents($htaccs_file, $file_contnt, FS_CHMOD_FILE);
                    }
                    remove_filter('upload_dir', 'foodsearch_public_upload_files_path');
                } else {
                    $template_files_dir = apply_filters('foodsearch_export_menu_template_files_dir', '');
                }

                if ($template_files_dir == '') {
                    return false;
                }
                
                $template_folder_name = 'menu-items-' . $menu_id . '-' . $current_time;
                $template_folder_name = apply_filters('foodsearch_export_menu_template_folder_name', $template_folder_name);
                
                $template_files_folder = $template_files_dir . '/' . $template_folder_name;
                if (!is_dir($template_files_folder)) {
                    wp_mkdir_p($template_files_folder);
                }
                
                $attachments_dir = $template_files_folder . '/attachments';
                if (!is_dir($attachments_dir)) {
                    wp_mkdir_p($attachments_dir);
                }
                
                $menu_items_arr = [];
                foreach ($results as $menu_item) {
                    
                    $menu_item_id = $menu_item->id;
                    
                    if ($menu_item->attachment_id > 0) {
                        $attch_file_path = get_attached_file($menu_item->attachment_id);
                        if (is_file($attch_file_path)) {
                            $img_dir = $attachments_dir . '/menu-' . $menu_item_id . '-pic/';
                            if (!is_dir($img_dir)) {
                                wp_mkdir_p($img_dir);
                            }
                            copy($attch_file_path, $img_dir . basename($attch_file_path));
                        }
                    }
                    
                    $category_data = '';
                    if ($menu_item->category_id > 0) {
                        $cat_id = $menu_item->category_id;
                        $category_data = ['id' => $cat_id];
                        $cat_term = get_term_by('id', $cat_id, 'food_item_cat');
                        if (isset($cat_term->name)) {
                            $category_data['name'] = $cat_term->name;
                        }
                    }
                    
                    $choice_groups_data = [];
                    if (!empty($menu_item->choice_groups_id) && $menu_item->choice_groups_id != NULL) {
                        $choice_groups = $menu_item->choice_groups_id;
                        $choice_groups = explode(',', $choice_groups);
                        
                        foreach ($choice_groups as $choice_group_id) {
                            $table_name = $table_prefix . 'menu_choice_group';
                            $sql = "SELECT * FROM $table_name WHERE id={$choice_group_id}";
                            $choice_group_result = $wpdb->get_results($sql, 'ARRAY_A');
                            if (isset($choice_group_result[0])) {
                                $choice_group_resdata = $choice_group_result[0];
                                
                                $choice_grp_menuitms = $choice_group_resdata['menuItem_id'];
                                $choice_grp_menuitms = json_decode($choice_grp_menuitms, true);
                                if (!empty($choice_grp_menuitms) && is_array($choice_grp_menuitms)) {
                                    foreach ($choice_grp_menuitms as $choice_grp_menuitm) {
                                        if (isset($choice_grp_menuitm['item_id']) && $choice_grp_menuitm['item_id'] > 0) {
                                            $choice_grp_menuitm_id = $choice_grp_menuitm['item_id'];
                                            $menuitm_data = self::get_choice_group_menuitm_data($choice_grp_menuitm_id, $menu_item_id, $attachments_dir);
                                            $choice_grp_menuitm['menu_item_data'] = $menuitm_data;
                                        }
                                        $menu_itms_data = $choice_grp_menuitm;
                                        $choice_group_resdata['menu_items_data'][] = $menu_itms_data;
                                    }
                                }
                                $choice_groups_data[$choice_group_id] = $choice_group_resdata;
                            }
                        }
                    }
                    
                    $nutritions_data = [];
                    $table_name = $table_prefix . 'menu_itemmeta';
                    $sql = "SELECT meta_value FROM $table_name WHERE menu_item_id={$menu_item_id} AND meta_key='item_nutritions'";
                    $nutritions_result = $wpdb->get_col($sql);
                    if (isset($nutritions_result[0])) {
                        $nutrition_results = $nutritions_result[0];
                        $nutrition_results = $nutrition_results != '' ? explode(',', $nutrition_results) : '';
                        
                        if (!empty($nutrition_results) && !empty($restaurant_nutritions_list)) {
                            foreach ($nutrition_results as $nutrition_id) {
                                if (isset($restaurant_nutritions_list[$nutrition_id])) {
                                    if (isset($restaurant_nutritions_list[$nutrition_id]['image']) && $restaurant_nutritions_list[$nutrition_id]['image'] > 0) {
                                        $nutri_attach_id = $restaurant_nutritions_list[$nutrition_id]['image'];
                                        $attch_file_path = get_attached_file($nutri_attach_id);
                                        if (is_file($attch_file_path)) {
                                            $img_dir = $attachments_dir . '/nutrition-' . $nutrition_id . '-pic/';
                                            if (!is_dir($img_dir)) {
                                                wp_mkdir_p($img_dir);
                                            }
                                            copy($attch_file_path, $img_dir . basename($attch_file_path));
                                        }
                                    }
                                    $nutritions_data[$nutrition_id] = $restaurant_nutritions_list[$nutrition_id];
                                }
                            }
                        }
                    }
                    
                    $apend_menu_itm = array(
                        'id' => $menu_item_id,
                        'name' => $menu_item->name,
                        'category_data' => $category_data,
                        'choice_group_data' => $choice_groups_data,
                        'nutritions_data' => $nutritions_data,
                        'price' => $menu_item->price,
                        'discount_price' => $menu_item->discount_price,
                        'offer_status' => $menu_item->offer_status,
                        'variations' => $menu_item->variations,
                        'details' => $menu_item->details,
                        'status' => $menu_item->status,
                        'sort_order' => $menu_item->sort_order,
                    );
                    
                    $menu_items_arr[] = $apend_menu_itm;
                }
                
                $result_json = json_encode($menu_items_arr);
                
                $menu_json_file = $template_files_folder . '/data.json';
                $wp_filesystem->put_contents($menu_json_file, $result_json, FS_CHMOD_FILE);
                
                if (!$export_outside) {
                    $menu_templates_list_key = 'fds_menu_items_save_templates';
                    $menu_templates_list = get_option($menu_templates_list_key);

                    $menu_templates_list = !empty($menu_templates_list) ? $menu_templates_list : array();

                    $menu_templates_list[$rand_id] = array(
                        'name' => $menu_name,
                        'template_folder' => $template_folder_name,
                        'formatted_time' => date('d M Y H:i:s', $current_time),
                        'time' => $current_time,
                    );
                    update_option($menu_templates_list_key, $menu_templates_list);
                    
                    return $menu_templates_list;
                } else {
                    
                    return array(
                        'name' => $menu_name,
                        'template_folder' => $template_folder_name,
                        'formatted_time' => date('d M Y H:i:s', $current_time),
                        'time' => $current_time,
                    );
                }
                //
                
            }
            //
        }
    }
    
    public static function get_choice_group_menuitm_data($menu_item_id, $parent_menu_item_id, $attachments_dir) {
        global $table_prefix, $wpdb;

        $table_name = $table_prefix . 'menu_items';
        $sql = "SELECT * FROM $table_name WHERE id={$menu_item_id}";
        $menu_items = $wpdb->get_results($sql, 'ARRAY_A');
        
        if (isset($menu_items[0])) {
            
            $menu_item = $menu_items[0];
            $category_data = '';
            if (isset($menu_item['category_id']) && $menu_item['category_id'] > 0) {
                $cat_id = $menu_item['category_id'];
                $category_data = ['id' => $cat_id];
                $cat_term = get_term_by('id', $cat_id, 'food_item_cat');
                if (isset($cat_term->name)) {
                    $category_data['name'] = $cat_term->name;
                }
            }
            $menu_item['category_id'] = $category_data;
            if (isset($menu_item['attachment_id']) && $menu_item['attachment_id'] > 0) {
                $attach_id = $menu_item['attachment_id'];
                $attch_file_path = get_attached_file($attach_id);
                if (is_file($attch_file_path)) {
                    $img_dir = $attachments_dir . '/choicegrp-' . $menu_item_id . '-pic/';
                    if (!is_dir($img_dir)) {
                        wp_mkdir_p($img_dir);
                        copy($attch_file_path, $img_dir . basename($attch_file_path));
                    }
                }
            }
            
            return $menu_item;
        }
    }
    
    public static function import_menu_item_template($template_id, $menu_id, $restaurant_id, $external_folder = '') {
        global $foodsearch_upload_files_extpath, $foodsearch_upload_subdir_extpath;
        
        $foodsearch_upload_files_extpath = 'templates';
        $foodsearch_upload_subdir_extpath = 'restaurant';

        $template_imported = false;
        
        $menu_templates_list = get_option('fds_menu_items_save_templates');
        $menu_templates_list = apply_filters('foodsearch_menu_items_save_templates_list', $menu_templates_list);
        
        if ($template_id > 0 && isset($menu_templates_list[$template_id])) {
            
            if ($external_folder != '') {
                $template_files_dir = $external_folder;
            } else {
                add_filter('upload_dir', 'foodsearch_public_upload_files_path');
                $wp_upload_dir = wp_upload_dir();
                $template_files_dir = $wp_upload_dir['path'] . '/restaurant-menu-templates';
                remove_filter('upload_dir', 'foodsearch_public_upload_files_path');
            }
            
            $menu_template = $menu_templates_list[$template_id];
            
            $template_folder = $template_files_dir . '/' . $menu_template['template_folder'] . '/';
            $template_file = $template_folder . 'data.json';
        }

        if (isset($template_folder) && isset($template_file) && is_dir($template_folder) && file_exists($template_file)) {
            $template_imported = true;
            require_once(ABSPATH . 'wp-admin/includes/file.php');
            WP_Filesystem();
            global $wp_filesystem;

            $template_data = $wp_filesystem->get_contents($template_file);
            $template_data = json_decode($template_data, true);
            if (!empty($template_data)) {
                global $foodsearch_imortin_temp_menuchoice;
                $foodsearch_imortin_temp_menuchoice = array();
                foreach ($template_data as $menu_item) {
                    self::import_menu_item_data($menu_item, $template_data, $template_folder, $menu_id, $restaurant_id);
                }
                if (!empty($foodsearch_imortin_temp_menuchoice)) {
                    self::create_choicegrps_for_import_menuitems($template_data, $template_folder, $menu_id, $restaurant_id);
                }
            }
        }
        
        return $template_imported;
    }
    
    public static function get_category_id($data_cat_id, $data_cat_name) {
        $category_id = '';
        $cat_term = get_term_by('id', $data_cat_id, 'food_item_cat');
        if (isset($cat_term->name) && $cat_term->name == $data_cat_name) {
            $category_id = $data_cat_id;
        }
        if ($category_id == '') {
            $cat_term = get_term_by('name', $data_cat_name, 'food_item_cat');
            if (isset($cat_term->term_id)) {
                $category_id = $cat_term->term_id;
            }
        }
        if ($category_id == '') {
            $new_cat = wp_insert_term($data_cat_name, 'food_item_cat');
            if (isset($new_cat->term_id)) {
                $category_id = $new_cat->term_id;
            }
        }
        
        return $category_id;
    }

    public static function import_menu_item_data($menu_item, $template_data, $template_folder, $menu_id, $restaurant_id, $predefine_restaurant_id = 0) {
        global $foodsearch_imortin_temp_menuchoice;
        if (isset($menu_item['name'])) {
            
            global $table_prefix, $wpdb;
            
            $menu_itm_id = $menu_item['id'];
            
            $table_name = $table_prefix . 'menu_itemmeta';
            $exist_meta_val = $menu_itm_id . '|' . $restaurant_id;
            $sql = "SELECT menu_item_id FROM $table_name WHERE meta_key='duplicate_item_orig_id' AND meta_value='{$exist_meta_val}'";
            $exist_menu_itm = $wpdb->get_col($sql);

            if (isset($exist_menu_itm[0]) && $exist_menu_itm[0] > 0) {
                return false;
            }

            require_once(ABSPATH . 'wp-admin/includes/file.php');
            WP_Filesystem();
            global $wp_filesystem;

            $menu_itm_name = $menu_item['name'];
            
            //
            // Adding Attachment
            //
            $mitem_attach_id = '';
            $itm_img_folder = $template_folder . 'attachments/menu-' . $menu_itm_id . '-pic/';
            $img_folder = $wp_filesystem->dirlist($itm_img_folder);
            $itm_img_path = '';
            if (!empty($img_folder)) {
                foreach ($img_folder as $img_folder_itm) {
                    if (isset($img_folder_itm['name'])) {
                        $itm_img_path = $itm_img_folder . $img_folder_itm['name'];
                        break;
                    }
                }
            }
            if ($itm_img_path != '' && is_file($itm_img_path)) {
                $mitem_attach_id = self::create_attachment($itm_img_path, $restaurant_id);
            }
            
            //
            // Adding cateory
            //
            $category_id = '';
            $cat_data = $menu_item['category_data'];
            if (isset($cat_data['name'])) {
                $data_cat_name = $cat_data['name'];
                $data_cat_id = $cat_data['id'];
                
                $category_id = self::get_category_id($data_cat_id, $data_cat_name);
            }
            
            //
            // Adding Nutritions
            //
            $nutritions_list = '';
            if ($predefine_restaurant_id > 0) {
                /*
                 * For Bulk Importer as Dummy Data
                 */
                $predefine_nutritions_list = get_post_meta($predefine_restaurant_id, 'foodsearch_nutritions_list', true);
                update_post_meta($restaurant_id, 'foodsearch_nutritions_list', $predefine_nutritions_list);
            }
            
            $restaurant_nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);

            $restaurant_nutritions_list = !empty($restaurant_nutritions_list) ? $restaurant_nutritions_list : array();
            $nutritions_data = $menu_item['nutritions_data'];
            if (!empty($nutritions_data)) {
                $nutritions_list_itms = [];
                foreach ($nutritions_data as $nutrition_id => $nutrition_itm) {
                    $data_nutri_title = $nutrition_itm['title'];
                    $data_nutri_image = $nutrition_itm['image'];
                    
                    $exist_nutri_itm = false;
                    if (isset($restaurant_nutritions_list[$nutrition_id]['title']) && $restaurant_nutritions_list[$nutrition_id]['title'] == $data_nutri_title) {
                        $exist_nutri_itm = true;
                        $nutritions_list_itms[] = $nutrition_id;
                    } else {
                        if (!empty($restaurant_nutritions_list)) {
                            foreach ($restaurant_nutritions_list as $resturnt_nutri_id => $resturnt_nutri_itm) {
                                if (isset($resturnt_nutri_itm['title']) && $resturnt_nutri_itm['title'] == $data_nutri_title) {
                                    $exist_nutri_itm = true;
                                    $nutritions_list_itms[] = $resturnt_nutri_id;
                                    break;
                                }
                            }
                        }
                    }
                    
                    if (!$exist_nutri_itm) {
                        /*
                         * Add New Nutrition Item
                         */
                        if ($data_nutri_image > 0) {
                            
                            $nutri_img_folder = $template_folder . 'attachments/nutrition-' . $nutrition_id . '-pic/';
                            $img_folder = $wp_filesystem->dirlist($nutri_img_folder);
                            $nutri_img_path = '';
                            if (!empty($img_folder)) {
                                foreach ($img_folder as $img_folder_itm) {
                                    if (isset($img_folder_itm['name'])) {
                                        $nutri_img_path = $nutri_img_folder . $img_folder_itm['name'];
                                        break;
                                    }
                                }
                            }
                            if ($nutri_img_path != '' && is_file($nutri_img_path)) {
                                $nutri_attach_id = self::create_attachment($nutri_img_path, $restaurant_id);
                                $new_nutrition_id = rand(1000000, 9999999);
                                $new_nutrition = array(
                                    'title' => $data_nutri_title,
                                    'image' => $nutri_attach_id
                                );
                                $restaurant_nutritions_list[$new_nutrition_id] = $new_nutrition;
                                update_post_meta($restaurant_id, 'foodsearch_nutritions_list', $restaurant_nutritions_list);
                                $nutritions_list_itms[] = $new_nutrition_id;
                            }
                        }
                    }
                }
                if (!empty($nutritions_list_itms)) {
                    $nutritions_list = implode(',', $nutritions_list_itms);
                }
            }
            
            //
            // Adding Choice Groups
            //
            $choice_groups_list = '';
            $choice_group_data = $menu_item['choice_group_data'];
            
            // Menu item name check
            $table_name = $table_prefix . 'menu_items';
            $sql = "SELECT id FROM $table_name WHERE name='{$menu_itm_name}' AND menu_id='{$menu_id}' AND restaurant_id='{$restaurant_id}'";
            $exist_menu_itm = $wpdb->get_col($sql);
            if (isset($exist_menu_itm[0]) && $exist_menu_itm[0] > 0) {
                //
            } else {
                $menu_item_data = array(
                    'name' => $menu_itm_name,
                    'price' => $menu_item['price'],
                    'discount_price' => $menu_item['discount_price'],
                    'offer_status' => $menu_item['offer_status'],
                    'attachment_id' => $mitem_attach_id,
                    'category_id' => $category_id,
                    'variations' => $menu_item['variations'],
                    'choice_groups_id' => $choice_groups_list,
                    'restaurant_id' => $restaurant_id,
                    'menu_id' => $menu_id,
                    'details' => $menu_item['details'],
                    'status' => $menu_item['status'],
                    'sort_order' => $menu_item['sort_order'],
                );

                $table_name = $table_prefix . 'menu_items';
                $wpdb->insert($table_name, $menu_item_data);

                $added_itm_id = $wpdb->insert_id;
                $foodsearch_imortin_temp_menuchoice[$added_itm_id] = $choice_group_data;
                
                if ($added_itm_id > 0 && $nutritions_list != '') {
                    $data = array();
                    $data['menu_item_id'] = $added_itm_id;
                    $data['meta_key'] = 'item_nutritions';
                    $data['meta_value'] = $nutritions_list;

                    $table_name = $table_prefix . 'menu_itemmeta';
                    $wpdb->insert($table_name, $data);
                }
            }
        }
    }

    public static function create_choice_group_menuitem($itm_id, $menuitm_data, $template_folder, $menu_id, $restaurant_id, $template_data) {
        global $table_prefix, $wpdb;
        
        // Menu item name check
        $table_name = $table_prefix . 'menu_items';
        $menu_itm_name = $menuitm_data['name'];
        $sql = "SELECT id FROM $table_name WHERE name='{$menu_itm_name}' AND menu_id='{$menu_id}' AND restaurant_id='{$restaurant_id}'";
        $exist_menu_itm = $wpdb->get_col($sql);
        if (isset($exist_menu_itm[0]) && $exist_menu_itm[0] > 0) {
            $menu_itm_id = $exist_menu_itm[0];
            
            return $menu_itm_id;
        }
        
        $table_name = $table_prefix . 'menu_itemmeta';
        $exist_meta_val = $itm_id . '|' . $restaurant_id;
        $sql = "SELECT menu_item_id FROM $table_name WHERE meta_key='duplicate_item_orig_id' AND meta_value='{$exist_meta_val}'";
        $exist_menu_itm = $wpdb->get_col($sql);
        
        if (isset($exist_menu_itm[0]) && $exist_menu_itm[0] > 0) {
            $menu_itm_id = $exist_menu_itm[0];
            
            return $menu_itm_id;
        } else {

            require_once(ABSPATH . 'wp-admin/includes/file.php');
            WP_Filesystem();
            global $wp_filesystem;

            $category_id = '';
            $cat_data = $menuitm_data['category_id'];

            if (isset($cat_data['name'])) {
                $data_cat_name = $cat_data['name'];
                $data_cat_id = $cat_data['id'];

                $category_id = self::get_category_id($data_cat_id, $data_cat_name);
            }

            $mitem_attach_id = '';
            $data_attach_id = $menuitm_data['attachment_id'];
            if ($data_attach_id > 0) {
                $choicegrp_img_folder = $template_folder . 'attachments/choicegrp-' . $itm_id . '-pic/';
                $img_folder = $wp_filesystem->dirlist($choicegrp_img_folder);
                $choicegrp_img_path = '';
                if (!empty($img_folder)) {
                    foreach ($img_folder as $img_folder_itm) {
                        if (isset($img_folder_itm['name'])) {
                            $choicegrp_img_path = $choicegrp_img_folder . $img_folder_itm['name'];
                            break;
                        }
                    }
                }
                if ($choicegrp_img_path != '' && is_file($choicegrp_img_path)) {
                    $mitem_attach_id = self::create_attachment($choicegrp_img_path, $restaurant_id);
                }
            }
            
            
            if (!empty($template_data)) {
                foreach ($template_data as $template_menu_itm) {
                    if (isset($template_menu_itm['name']) && $template_menu_itm['name'] == $menu_itm_name) {
                        $orig_menuitm_data = $template_menu_itm;
                    }
                }
            }
            
            //
            // Adding Choice Groups
            //
            $choice_groups_list = '';

            $menu_item_data = array(
                'name' => $menuitm_data['name'],
                'price' => $menuitm_data['price'],
                'discount_price' => $menuitm_data['discount_price'],
                'offer_status' => $menuitm_data['offer_status'],
                'attachment_id' => $mitem_attach_id,
                'category_id' => $category_id,
                'variations' => $menuitm_data['variations'],
                'choice_groups_id' => $choice_groups_list,
                'restaurant_id' => $restaurant_id,
                'menu_id' => $menu_id,
                'details' => $menuitm_data['details'],
                'status' => $menuitm_data['status'],
                'sort_order' => $menuitm_data['sort_order'],
            );

            $table_name = $table_prefix . 'menu_items';
            $wpdb->insert($table_name, $menu_item_data);

            $menu_itm_id = $wpdb->insert_id;
            if ($menu_itm_id > 0) {
                $data = array();
                $data['menu_item_id'] = $menu_itm_id;
                $data['meta_key'] = 'duplicate_item_orig_id';
                $data['meta_value'] = $exist_meta_val;

                $table_name = $table_prefix . 'menu_itemmeta';
                $wpdb->insert($table_name, $data);
            }

            return $menu_itm_id;
        }
    }
    
    public static function create_choicegrps_for_import_menuitems($template_data, $template_folder, $menu_id, $restaurant_id) {
        global $foodsearch_imortin_temp_menuchoice, $table_prefix, $wpdb;

        foreach ($foodsearch_imortin_temp_menuchoice as $menu_itm_id => $choice_group_data) {
            //
            // Adding Choice Groups
            //
            $choice_groups_list = '';
            if (!empty($choice_group_data)) {
                $pass_choice_grp_ids = [];
                foreach ($choice_group_data as $choicgrp_data_itm) {
                    $choic_grp_id = absint($choicgrp_data_itm['id']);
                    $choic_grp_name = $choicgrp_data_itm['name'];
                    $table_name = $table_prefix . 'menu_choice_group';
                    
                    $sql = "SELECT restaurant_id FROM $table_name WHERE id={$choic_grp_id}";
                    $choice_group_restaurnt = $wpdb->get_col($sql);
                    
                    $choicegrp_exists = false;
                    if (isset($choice_group_restaurnt[0]) && $choice_group_restaurnt[0] == $restaurant_id) {
                        $choicegrp_exists = true;
                        $pass_choice_grp_ids[] = $choic_grp_id;
                    } else {
                        $sql = "SELECT id FROM $table_name WHERE restaurant_id={$restaurant_id} AND name='{$choic_grp_name}'";
                        $choicegrp_result = $wpdb->get_col($sql);
                        if (isset($choicegrp_result[0]) && $choicegrp_result[0] > 0) {
                            $choicegrp_exists = true;
                            $pass_choice_grp_ids[] = $choicegrp_result[0];
                        }
                    }
                    
                    if (!$choicegrp_exists) {
                        $choicgrp_menuitms_arr = [];
                        $choicgrp_menu_itmdata = $choicgrp_data_itm['menu_items_data'];
                        foreach ($choicgrp_menu_itmdata as $menu_itm_data) {
                            $itm_id = $menu_itm_data['item_id'];
                            $itm_price = $menu_itm_data['item_price'];
                            $new_menuitm_data = $menu_itm_data['menu_item_data'];
                            $menu_itm_name = $new_menuitm_data['name'];
                            
                            $table_name = $table_prefix . 'menu_items';
                            $sql = "SELECT id FROM $table_name WHERE name='{$menu_itm_name}' AND menu_id='{$menu_id}' AND restaurant_id='{$restaurant_id}'";
                            $exist_menu_itm = $wpdb->get_col($sql);
                            if (isset($exist_menu_itm[0]) && $exist_menu_itm[0] > 0) {
                                $new_menuitm_id = $exist_menu_itm[0];
                            } else {
                                $new_menuitm_id = self::create_choice_group_menuitem($itm_id, $new_menuitm_data, $template_folder, $menu_id, $restaurant_id, $template_data);
                            }
                            
                            if ($new_menuitm_id > 0) {
                                $choicgrp_menuitms_arr[] = array(
                                    'item_id' => (string) $new_menuitm_id,
                                    'item_price' => $itm_price,
                                );
                            }
                        }
                        $choicgrp_menuitms_str = '';
                        if (!empty($choicgrp_menuitms_arr)) {
                            $choicgrp_menuitms_str = json_encode($choicgrp_menuitms_arr);
                        }
                        $new_choicgrp_data = $choicgrp_data_itm;
                        unset($new_choicgrp_data['id']);
                        unset($new_choicgrp_data['menu_items_data']);
                        $new_choicgrp_data['restaurant_id'] = $restaurant_id;
                        $new_choicgrp_data['menuItem_id'] = $choicgrp_menuitms_str;
                        $table_name = $table_prefix . 'menu_choice_group';
                        $wpdb->insert($table_name, $new_choicgrp_data);
                        $new_choicgrp_id = $wpdb->insert_id;
                        $pass_choice_grp_ids[] = $new_choicgrp_id;
                    }
                }
                if (!empty($pass_choice_grp_ids)) {
                    $choice_groups_list = implode(',', $pass_choice_grp_ids);
                }
                
                $data = array();
                $data['choice_groups_id'] = $choice_groups_list;
                $where['id'] = $menu_itm_id;

                $table_name = $table_prefix . 'menu_items';
                $wpdb->update($table_name, $data, $where);
            }
        }
    }
    
    public static function create_attachment($img_path, $restaurant_id) {
        $common_functions = new Common_Functions;
        
        $user_id = Common_Functions::restaurant_user_id($restaurant_id);
        
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        WP_Filesystem();
        global $wp_filesystem;
        
        $upload_dir = wp_upload_dir();
        
        $image_data = $wp_filesystem->get_contents($img_path);
        
        $filename = 'img-' . rand(10000000, 99999999) . '-' . basename($img_path);
        if (wp_mkdir_p($upload_dir['path'])) {
            $upload_img_path = $upload_dir['path'] . '/' . $filename;
        } else {
            $upload_img_path = $upload_dir['basedir'] . '/' . $filename;
        }
        $wp_filesystem->put_contents($upload_img_path, $image_data);
        
        $wp_filetype = wp_check_filetype($filename, null);
        $attachment = array(
            'post_mime_type' => $wp_filetype['type'],
            'post_title' => sanitize_file_name($filename),
            'post_content' => '',
            'post_status' => 'inherit',
            'post_author' => $user_id
        );
        $attach_id = wp_insert_attachment($attachment, $upload_img_path, $restaurant_id);

        $attach_data = wp_generate_attachment_metadata($attach_id, $upload_img_path);
        wp_update_attachment_metadata($attach_id, $attach_data);
        
        return $attach_id;
    }

    public function admin_page() {
        add_submenu_page('edit.php?post_type=restaurants', esc_html__('Menu Templates', 'wp-foodsearch'), esc_html__('Menu Templates', 'wp-foodsearch'), 'administrator', 'menu-templates', array($this, 'menu_templates_page'));
    }
    
    public function menu_templates_page() {
        global $foodsearch_upload_files_extpath, $foodsearch_upload_subdir_extpath;
        
        $foodsearch_upload_files_extpath = 'templates';
        $foodsearch_upload_subdir_extpath = 'restaurant';
        
        $menu_templates_list = get_option('fds_menu_items_save_templates');
        ?>
        <div class="fds-menu-templates-page">
            <div class="templates-page-title-con"><strong><?php esc_html_e('saved menu templates', 'wp-foodsearch') ?></strong></div>
            <div class="fds-menu-templates-list">
                <?php
                if (!empty($menu_templates_list)) {

                    uasort($menu_templates_list, function ($a, $b) {
                        if ($a['time'] == $b['time']) {
                            $ret_val = 0;
                        }
                        $ret_val = ($b['time'] < $a['time']) ? -1 : 1;
                        return $ret_val;
                    });
                    
                    add_filter('upload_dir', 'foodsearch_public_upload_files_path');
                    $wp_upload_dir = wp_upload_dir();
                    $template_files_dir = $wp_upload_dir['path'] . '/restaurant-menu-templates';
                    remove_filter('upload_dir', 'foodsearch_public_upload_files_path');

                    $temp_counts = 1;
                    foreach ($menu_templates_list as $template_id => $menu_template) {

                        $template_folder = $template_files_dir . '/' . $menu_template['template_folder'] . '/';

                        $template_file = $template_folder . 'data.json';

                        if (is_dir($template_folder) && file_exists($template_file)) {
                            $have_templates = true;
                            $template_name = $menu_template['name'];
                            $image_id = isset($menu_template['image_id']) ? $menu_template['image_id'] : '';
                            $template_datetime = $menu_template['formatted_time'];
                            ?>
                            <div id="template-<?php echo ($template_id) ?>" class="fds-menu-template-itm">
                                <?php
                                $img_src = '';
                                $has_img = false;
                                ob_start();
                                if ($image_id != '' && $image = wp_get_attachment_image_src($image_id, 'full')) {
                                    $has_img = true;
                                    $img_src = $image[0];
                                }
                                ?>
                                <img src="<?php echo ($img_src) ?>"<?php echo ($img_src != '' ? '' : ' style="display:none;"') ?> alt="">
                                <i class="fds-icon fds-food-fire"<?php echo ($img_src == '' ? '' : ' style="display:none;"') ?>></i>
                                <?php
                                $icon_html = ob_get_clean();
                                ?>
                                <div class="fds-template-icon-con<?php echo ($has_img ? ' fds-has-img' : '') ?>">
                                    <?php echo ($icon_html) ?>
                                </div>
                                <div class="fds-template-actbtns">
                                    <a href="#" class="fds-preview-menu-template fds-link"<?php echo ($img_src != '' ? '' : ' style="display:none;"') ?> data-target-img="<?php echo ($img_src) ?>" data-tid="<?php echo ($template_id) ?>"><i class="fds-icon fds-eye-line"></i></a>
                                    <a href="#" class="fds-del-menu-template fds-link" data-tid="<?php echo ($template_id) ?>"><i class="fds-icon fds-time-simple"></i></a>
                                </div>
                                <div class="fds-template-import-con">
                                    <a href="#" class="fds-import-menu-template fds-settins-menu-template fds-link" data-tid="<?php echo ($template_id) ?>"><?php esc_html_e('settings', 'wp-foodsearch') ?></a>
                                    <strong class="fds-template-name"><?php echo ($template_name) ?></strong>
                                    <span class="fds-template-datetime" style="display:none;"><?php echo ($template_datetime) ?></span>
                                </div>
                            </div>
                            <?php
                            $temp_counts++;
                        }
                    }

                } else {
                    ?>
                    <div class="foodsearch-noitm-found">
                        <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                        <p><?php esc_html_e('no saved templates found.', 'wp-foodsearch') ?></p>
                    </div>
                    <?php
                }
                ?>
            </div>
        </div>
        <?php
        add_action('admin_footer', function() {
            ?>
            <div id="menu-template-settin-popup" class="fds-modal-popup fds-popup-hide fds-template-settin-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        });
    }
}

new Restaurant_Menu_Templates;
