<?php

namespace FoodSearch;
use FoodSearch\user_orders as FoodSearch_Orders;
use FoodSearch\Common_Functions;

class User_Reviews {
    
    public function __construct() {
        add_action('wp_enqueue_scripts', array($this, 'enqueue_style_scripts'), 50);
        
        add_action('rest_api_init', array($this, 'register_api'), 5);
        
        add_filter('foodsearch_customer_dash_orders_list_after_title', array($this, 'in_order_customer_review'), 10, 2);
        
        add_filter('foodsearch_customer_dash_orders_list_after', array($this, 'html_customer_review_popup'));
        
        add_filter('foodsearch_restaurant_detail_top_after_min_order', array($this, 'totl_avg_review_in_detail'), 10, 2);
        
        add_filter('foodsearch_restaurant_single_after_tab_1_itm', array($this, 'single_restaurant_reviews_tab'), 10, 2);
        add_filter('foodsearch_restaurant_single_after_tab_1_content', array($this, 'single_restaurant_reviews_list'), 10, 2);
    }
    
    public function register_api() {

        register_rest_route('wp/v1', 'add-customer-review-form', array(
            'methods' => 'POST',
            'callback' => [$this, 'customer_review_form'],
           'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'customer-order-review-submit', array(
            'methods' => 'POST',
            'callback' => [$this, 'customer_review_submit'],
           'permission_callback' =>  'admin_permissions_check',
        ));
    }
    
    public function enqueue_style_scripts() {
        
        wp_register_script('foodsearch-reviews', foodsearch_plugin_get_url('assets/js/reviews-rating.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
    }
    
    public function in_order_customer_review($html, $order_id) {
        global $foodsearch_plugin_settings;
        
        $reviews_switch = isset($foodsearch_plugin_settings['review_settings']['enable_reviews']) ? $foodsearch_plugin_settings['review_settings']['enable_reviews'] : '';
        
        if ($reviews_switch == 'on') {
            
            $user_id = get_current_user_id();

            $order_meta = FoodSearch_Orders::get_order_meta($order_id);
            $order_review_data = FoodSearch_Orders::order_meta_value($order_meta, 'review_data');
            $order_review_data = maybe_unserialize($order_review_data);
            
            ob_start();
            if (isset($order_review_data['rating'])) {
                $over_all_avg_rting = $order_review_data['rating'];
                $over_all_avg_rting_perc = 0;
                if ($over_all_avg_rting > 0) {
                    $over_all_avg_rting_perc = ($over_all_avg_rting / 5) * 100;
                }
                ?>
                <div class="fds-order-rated">
                    <div class="fds-rating-stars">
                        <span class="fds-rating-stars-fill" style="width: <?php echo($over_all_avg_rting_perc) ?>%;"></span>
                    </div>
                </div>
                <?php
            } else {
                $order_data = FoodSearch_Orders::get_order_by_id($order_id);
                if (isset($order_data[0]['status']) && $order_data[0]['status'] == 'completed') {
                    ?>
                    <a href="#" class="add-review-popbtn fds-link" data-id="<?php echo ($order_id) ?>" data-nid="<?php echo ($user_id) ?>"><i class="fds-icon fds-rate"></i> <?php esc_html_e('give a review', 'wp-foodsearch'); ?></a>
                    <?php
                }
            }
            $html .= ob_get_clean();
        }
        
        return $html;
    }
    
    public function html_customer_review_popup($html) {
        global $foodsearch_plugin_settings;
        
        $reviews_switch = isset($foodsearch_plugin_settings['review_settings']['enable_reviews']) ? $foodsearch_plugin_settings['review_settings']['enable_reviews'] : '';
        
        if ($reviews_switch == 'on') {
            wp_enqueue_script('foodsearch-reviews');
            
            add_action('wp_footer', function() {
                ?>
                <div id="order-review-popup" class="fds-modal-popup fds-popup-hide fds-order-review-popup">
                    <div class="fds-modal-container">
                        <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                        <div class="fds-modal-inner-area">
                            <div class="fds-modal-content-area">
                                <div class="fds-dynm-modal-content">
                                    <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }, 20);
        }
        
        return $html;
    }
    
    private function review_titles_arr() {
        global $foodsearch_plugin_settings;
        
        $titles_arr = isset($foodsearch_plugin_settings['review_settings']['review_titles']) ? $foodsearch_plugin_settings['review_settings']['review_titles'] : '';
        
        $review_titles = array();
        if (!empty($titles_arr) && is_array($titles_arr)) {
            foreach ($titles_arr as $title) {
                if ($title != '') {
                    $review_titles[] = $title;
                }
            }
        }
        return $review_titles;
    }
    
    public function customer_review_form() {

        $order_id = $_POST['order_id'];
        $user_id = $_POST['n_id'];
        
        $comment_id = 0;
        if (isset($_POST['com_id']) && $_POST['com_id'] > 0) {
            $comment_id = $_POST['com_id'];
        }
        
        $title_txt = esc_html__('give a review', 'wp-foodsearch');
        $label_txt = esc_html__('write your review', 'wp-foodsearch');
        if ($comment_id > 0) {
            $title_txt = esc_html__('reply', 'wp-foodsearch');
            $label_txt = esc_html__('write your reply', 'wp-foodsearch');
        }
        
        $review_titles = $this->review_titles_arr();
        ob_start();
        ?>
        <div class="fds-booking-detail-title"><h2 class="fds-heading-title"><?php echo ($title_txt) ?></h2></div>
        <div class="fds-plugin-modal-box-inner">
            <div class="fds-review-form-con">
                <form autocomplete="off" id="customer-order-review-form" class="fds-addreview-form fds-update-anything-action" method="post">
                    <?php
                    if ($comment_id == 0) {
                        ?>
                        <div class="fds-reviewsecs-con">
                            <div class="review-stars-sec">
                                <?php
                                if (!empty($review_titles)) {
                                    $review_title_count = 1;
                                    foreach ($review_titles as $review_title) {
                                        ?>
                                        <div class="review-stars-holder">
                                            <label class="fds-input-label"><?php echo ($review_title) ?></label>
                                            <select id="review-stars-selector-<?php echo ($review_title_count) ?>" name="user_rating_<?php echo ($review_title_count) ?>" autocomplete="off">
                                                <option value="1">1</option>
                                                <option value="2">2</option>
                                                <option value="3">3</option>
                                                <option value="4">4</option>
                                                <option value="5">5</option>
                                            </select>
                                        </div>
                                        <?php
                                        $review_title_count++;
                                    }
                                } else { ?>
                                    <div class="review-stars-holder">
                                        <label class="fds-input-label"><?php esc_html_e("rating", "wp-foodsearch") ?></label>
                                        <select id="review-stars-selector" name="user_rating_1" autocomplete="off">
                                            <option value="1">1</option>
                                            <option value="2">2</option>
                                            <option value="3">3</option>
                                            <option value="4">4</option>
                                            <option value="5">5</option>
                                        </select>
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <?php
                            $def_width = '20%;';
                            ?>
                            <div class="review-overall-stars-sec">
                                <div class="review-overall-stars-iner">
                                    <span class="rating-text"><?php esc_html_e("overall rating", "wp-foodsearch") ?></span>
                                    <span class="rating-num">0</span>
                                    <div class="fds-rating-stars fds-company-rating">
                                        <span class="fds-ovrall-rting-asignr fds-rate1" data-rate="1">&nbsp;</span>
                                        <span class="fds-ovrall-rting-asignr fds-rate2" data-rate="2">&nbsp;</span>
                                        <span class="fds-ovrall-rting-asignr fds-rate3" data-rate="3">&nbsp;</span>
                                        <span class="fds-ovrall-rting-asignr fds-rate4" data-rate="4">&nbsp;</span>
                                        <span class="fds-ovrall-rting-asignr fds-rate5" data-rate="5">&nbsp;</span>
                                        <span class="fds-rating-stars-fill fds-company-rating-box" style="width: <?php echo ($def_width) ?>;"></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                    ?>
                    <div class="fds-form-field">
                        <textarea name="user_comment" class="fds-textarea-style" placeholder="<?php echo ($label_txt) ?>"></textarea>
                        <input type="hidden" name="review_order" value="<?php echo absint($order_id) ?>">
                        <input type="hidden" name="nid" value="<?php echo absint($user_id) ?>">
                        <input type="hidden" name="com_id" value="<?php echo absint($comment_id) ?>">
                    </div>
                    <div class="fds-btn fds-medium-btn">
                        <button type="submit" class="fds-has-bg" id="fds-review-submit-btn"><?php esc_html_e("submit", "wp-foodsearch") ?></button>
                    </div>
                    <?php
                    wp_nonce_field('user_order_review', '_nonce');
                    ?>
                </form>
            </div>
        </div>
        <?php
        $html = ob_get_clean();
        
        wp_send_json(array('html' => $html));
    }
    
    private function user_avg_review_asign_to_arr($arr = array(), $rate = 1) {
        if ($rate > 0 && $rate < 2) {
            $arr['rating_1'] += 1;
        } else if ($rate >= 2 && $rate < 3) {
            $arr['rating_2'] += 1;
        } else if ($rate >= 3 && $rate < 4) {
            $arr['rating_3'] += 1;
        } else if ($rate >= 4 && $rate < 5) {
            $arr['rating_4'] += 1;
        } else {
            $arr['rating_5'] += 1;
        }
        return $arr;
    }

    private function user_review_asign_to_arr($arr = array(), $rate = '1') {
        switch ($rate) {
            case '1':
                $arr['rating_1'] += 1;
                break;
            case '2':
                $arr['rating_2'] += 1;
                break;
            case '3':
                $arr['rating_3'] += 1;
                break;
            case '4':
                $arr['rating_4'] += 1;
                break;
            case '5':
                $arr['rating_5'] += 1;
                break;
        }
        return $arr;
    }
    
    public function customer_review_submit() {

        global $foodsearch_user_orders_obj;

        $review_text_length = 5000;
        
        $manual_approve = false;

        $time = current_time('mysql');

        $common_funcs = new Common_Functions;
        
        $review_order_id = isset($_POST['review_order']) ? $_POST['review_order'] : '';
        $user_comment = isset($_POST['user_comment']) ? $_POST['user_comment'] : '';
        $reply_com_id = isset($_POST['com_id']) ? $_POST['com_id'] : '';
        $reply_com_id = absint($reply_com_id);

        $user_id = isset($_POST['nid']) ? $_POST['nid'] : '';
        
        $order_meta = FoodSearch_Orders::get_order_meta($review_order_id);

        $restaurant_id = FoodSearch_Orders::order_meta_value($order_meta, 'restaurant_id');
        $restaurant_user_id = Common_Functions::restaurant_user_id($restaurant_id);
        $order_review_data = FoodSearch_Orders::order_meta_value($order_meta, 'review_data');
        
        $user_can_post = true;
        if (!empty($order_review_data) && $user_id != $restaurant_user_id && $reply_com_id == 0) {
            $user_can_post = false;
        }

        if ($user_can_post) {

            if ($user_comment == '') {
                $msg = esc_html__("review text cannot be blank.", "wp-foodsearch");
                wp_send_json(array('msg' => $msg, 'error' => '1'));
            }
            if (strlen($user_comment) > $review_text_length) {
                $msg = sprintf(esc_html__("the maximum review text allowed is %s characters.", "wp-foodsearch"), $review_text_length);
                wp_send_json(array('msg' => $msg, 'error' => '1'));
            }
            
            if ($reply_com_id == 0) {

                $review_titles = $this->review_titles_arr();

                $review_user_rate = array();

                if (!empty($review_titles)) {
                    $review_title_count = 1;
                    foreach ($review_titles as $review_title) {
                        $review_user_rate['user_rating_' . $review_title_count] = isset($_POST['user_rating_' . $review_title_count]) && absint($_POST['user_rating_' . $review_title_count]) > 0 ? $_POST['user_rating_' . $review_title_count] : 1;
                        $review_title_count++;
                    }
                } else {
                    $review_user_rate['user_rating_1'] = isset($_POST['user_rating_1']) && absint($_POST['user_rating_1']) > 0 ? $_POST['user_rating_1'] : 1;
                }
                //
                $total_rating = 0;
                $num_ratings = 0;
                foreach ($review_user_rate as $review_user_rat_key => $review_user_rat_val) {
                    $review_user_rat_val = absint($review_user_rat_val) > 5 ? 5 : absint($review_user_rat_val);
                    $total_rating += $review_user_rat_val;
                    $num_ratings++;
                }
                $avg_rating = 1;
                if ($total_rating > 0 && $num_ratings > 0) {
                    $avg_rating = $total_rating / $num_ratings;
                }
            }
            
            $user_obj = get_user_by('ID', $user_id);
            $user_name = $user_obj->display_name;
            $user_email = $user_obj->user_email;

            $review_data = array(
                'comment_post_ID' => $restaurant_id,
                'comment_author' => $user_name,
                'comment_author_email' => $user_email,
                'comment_author_url' => '',
                'comment_content' => $user_comment,
                'comment_type' => '',
                'comment_parent' => ($reply_com_id > 0 ? $reply_com_id : 0),
                'user_id' => $user_id,
                'comment_author_IP' => '',
                'comment_agent' => '',
                'comment_date' => $time,
                'comment_approved' => ($manual_approve ? 0 : 1),
            );
            $comment_id = wp_insert_comment($review_data);

            if ($reply_com_id == 0) {

                add_comment_meta($comment_id, 'review_order_id', $review_order_id);
                add_comment_meta($comment_id, 'review_avg_rating', $avg_rating);
                add_comment_meta($comment_id, 'review_overall_rating', $review_user_rate);

                $review_order_data = array(
                    'rating' => $avg_rating,
                    'overall_rating' => $review_user_rate,
                    'comment_id' => $comment_id,
                );
                $review_order_data = maybe_serialize($review_order_data);
                $foodsearch_user_orders_obj->save_order_meta($review_order_id, 'review_data', $review_order_data);

                // updating review Post
                $all_avg_ratings = $all_overall_ratings = array(
                    'rating_1' => 0,
                    'rating_2' => 0,
                    'rating_3' => 0,
                    'rating_4' => 0,
                    'rating_5' => 0,
                );

                $args = array(
                    'post_id' => $restaurant_id,
                    'parent' => 0,
                    'status' => 'approve',
                );
                $all_comments = get_comments($args);

                $all_avg_ratingee = 0;
                $count_reviews = 0;
                $overall_user_rate = array();

                if (!empty($all_comments)) {
                    foreach ($all_comments as $r_comment) {
                        if (isset($r_comment->comment_ID)) {
                            $com_id = $r_comment->comment_ID;
                            $rev_avg_rating = get_comment_meta($com_id, 'review_avg_rating', true);
                            $all_avg_ratings = $this->user_avg_review_asign_to_arr($all_avg_ratings, $rev_avg_rating);

                            $all_avg_ratingee += absint($rev_avg_rating);

                            $rev_overall_rating = get_comment_meta($com_id, 'review_overall_rating', true);
                            if (!empty($rev_overall_rating)) {
                                $review_title_count = 1;
                                foreach ($rev_overall_rating as $review_title_rate) {
                                    $overall_user_rate['user_rating_' . $review_title_count] = $this->user_review_asign_to_arr($all_overall_ratings, $review_title_rate);
                                    $review_title_count++;
                                }
                            }
                            $count_reviews++;
                        }
                    }

                    $all_avg_ratingee = $all_avg_ratingee / $count_reviews;
                }

                update_post_meta($restaurant_id, 'oveall_review_avg_rating', $all_avg_ratingee);
                update_post_meta($restaurant_id, 'oveall_review_avg_ratings', $all_avg_ratings);
                update_post_meta($restaurant_id, 'oveall_review_overall_ratings', $overall_user_rate);
                update_post_meta($restaurant_id, 'oveall_review_count', $count_reviews);
            }

            //
            if ($manual_approve) {
                //
                $msg = esc_html__("review is submitted for admin approval.", "wp-foodsearch");
            } else {

                if ($reply_com_id > 0) {
                    $msg = esc_html__("reply submitted successfully.", "wp-foodsearch");
                } else {
                    $msg = esc_html__("review submit successfully.", "wp-foodsearch");
                }
            }
            wp_send_json(array('msg' => $msg, 'error' => '0'));
            //
        } else {
            $msg = esc_html__("you have already reviewed against this order.", "wp-foodsearch");
            wp_send_json(array('msg' => $msg, 'error' => '1'));
        }
    }
    
    public static function restaurant_avg_review_rate($restaurant_id) {
        global $foodsearch_plugin_settings;
        
        $reviews_switch = isset($foodsearch_plugin_settings['review_settings']['enable_reviews']) ? $foodsearch_plugin_settings['review_settings']['enable_reviews'] : '';
        
        if ($reviews_switch == 'on') {
            $reviews_count = get_post_meta($restaurant_id, 'oveall_review_count', true);
            
            $over_all_avg_rting = 0;
            $over_all_avg_rting_perc = 0;
            $oveall_review_avg_rating = get_post_meta($restaurant_id, 'oveall_review_avg_rating', true);
            if ($oveall_review_avg_rating > 0) {
                $over_all_avg_rting = number_format($oveall_review_avg_rating, 1);
                $over_all_avg_rting_perc = ($oveall_review_avg_rating / 5) * 100;
            }

            $avg_review = array(
                'rating' => $over_all_avg_rting,
                'percentage' => $over_all_avg_rting_perc,
                'count' => $reviews_count,
            );
            
            return $avg_review;
        }
    }
    
    public function totl_avg_review_in_detail($html, $restaurant_id) {
        
        $avg_rate = self::restaurant_avg_review_rate($restaurant_id);
        $reviews_count = 0;
        if ( isset($avg_rate['count']) ) $reviews_count = $avg_rate['count'];
        
        if ($reviews_count > 0 && isset($avg_rate['rating'])) {
            $over_all_avg_rting = $avg_rate['rating'];
            $over_all_avg_rting_perc = $avg_rate['percentage'];
            ob_start();
            ?>
            <div class="fds-restaurant-listing-detail-submin">
                <div class="fds-rating-stars">
                    <span class="fds-rating-stars-fill" style="width: <?php echo ($over_all_avg_rting_perc) ?>%;"></span>
                </div>
                <span class="fds-restaurant-list-rate"><?php printf(esc_html__("%s review(s)", "wp-foodsearch"), absint($reviews_count)) ?> <small><?php echo ($over_all_avg_rting); ?>/5</small></span>
            </div>
            <?php
            $html .= ob_get_clean();
        }
        
        return $html;
    }
    
    public function single_restaurant_reviews_tab($html) {
        
        global $foodsearch_plugin_settings;
        
        $reviews_switch = isset($foodsearch_plugin_settings['review_settings']['enable_reviews']) ? $foodsearch_plugin_settings['review_settings']['enable_reviews'] : '';
        
        if ($reviews_switch == 'on') {
            ob_start();
            ?>
            <li class="fds-list-item"><a id="tab-reviews" data-toggle="tab" href="#tabref-reviews" class="fds-link"><i class="fds-icon fds-comment"></i> <?php esc_html_e("reviews", "wp-foodsearch") ?></a></li>
            <?php
            $html .= ob_get_clean();
        }
        
        return $html;
    }
    
    public function reviews_list_item($r_comment, $restaurant_id) {
        $common_funcs = new Common_Functions;
        
        $com_id = $r_comment->comment_ID;
        $comment_date = strtotime($r_comment->comment_date);

        $user_id = $r_comment->user_id;
        $customer_id = Common_Functions::user_customer_id($user_id);

        $rev_avg_rating = get_comment_meta($com_id, 'review_avg_rating', true);
        $rev_overall_rating = get_comment_meta($com_id, 'review_overall_rating', true);

        $_avg_rting_perc = 0;
        if ($rev_avg_rating > 0) {
            $_avg_rting_perc = ($rev_avg_rating / 5) * 100;
        }

        $rev_avg_rating = $rev_avg_rating > 0 ? $rev_avg_rating : 0;

        $review_order_id = get_comment_meta($com_id, 'review_order_id', true);
        
        $review_overall_rating = get_comment_meta($com_id, 'review_overall_rating', true);

        $photo_url = foodsearch_customer_photo_url($user_id);

        $coment_rplies = false;
        ?>
        <li class="fds-list-item">
            <div class="fds-dashboard-reviews-list-inner">
                <div class="fds-item-thumb"><a href="<?php echo get_permalink($customer_id) ?>" class="fds-link"><img src="<?php echo ($photo_url) ?>" alt=""></a></div>
                <div class="fds-dashboard-reviews-text">
                    <span class="fds-dashboard-reviews-text-title"><?php echo get_the_title($customer_id) ?></span>
                    <small><?php echo (foodsearch_time_elapsed_string($comment_date)) ?></small>
                    <div class="fds-rating-calc-wrap">
                        <div class="fds-rating-stars"> <span class="fds-rating-stars-fill" style="width: <?php echo($_avg_rting_perc) ?>%;"></span> </div>
                        <?php
                        if (!empty($review_overall_rating) && count($review_overall_rating) > 1) {
                            $review_titles = $this->review_titles_arr();
                            ?>
                            <div class="fds-user-all-ratings">
                                <?php
                                $ratin_num = 0;
                                foreach ($review_overall_rating as $rate_key => $rate_val) {
                                    $rate_avg_perc = 0;
                                    if ($rate_val > 0) {
                                        $rate_avg_perc = ($rate_val / 5) * 100;
                                    }
                                    if (isset($review_titles[$ratin_num])) {
                                        ?>
                                        <div class="fds-user-rate-item">
                                            <span class="fds-user-rate-label"><?php echo ($review_titles[$ratin_num]) ?></span>
                                            <div class="fds-rating-stars"> <span class="fds-rating-stars-fill" style="width: <?php echo ($rate_avg_perc) ?>%;"></span> </div>
                                        </div>
                                        <?php
                                    }
                                    $ratin_num++;
                                }
                                ?>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <p><?php echo ($r_comment->comment_content) ?></p>
                    <?php
                    $reply_com_args = array(
                        'post_id' => $restaurant_id,
                        'parent' => $com_id,
                    );
                    $reply_comments = get_comments($reply_com_args);
                    if (empty($reply_comments)) {
                        if (is_user_logged_in()) {
                            $curent_user_id = get_current_user_id();
                            if ($restaurant_id == Common_Functions::user_restaurant_id($curent_user_id)) {
                                ?>
                                <a href="#" class="add-reviewrply-popbtn fds-link" data-id="<?php echo ($review_order_id) ?>" data-cid="<?php echo ($com_id) ?>" data-nid="<?php echo ($user_id) ?>"><?php esc_html_e("reply", "wp-foodsearch") ?></a>
                                <?php
                            }
                        }
                    } else {
                        $coment_rplies = true;
                    }
                    ?>
                </div>
            </div>
        </li>
        <?php
        if ($coment_rplies) {
            foreach ($reply_comments as $rply_com) {
                $this->comment_reply_html($rply_com, $restaurant_id);
            }
        }
    }
    
    public function restaurant_reviews_list($restaurant_id) {
        
        $com_args = array(
            'post_id' => $restaurant_id,
            'parent' => 0,
            'status' => 'approve',
        );
        $all_comments = get_comments($com_args);
        if (!empty($all_comments)) {
            $avg_rate = self::restaurant_avg_review_rate($restaurant_id);
        
            $reviews_count = $over_all_avg_rting = $over_all_avg_rting_perc = 0;
            if (isset($avg_rate['rating'])) {
                $reviews_count = $avg_rate['count'];
                $over_all_avg_rting = $avg_rate['rating'];
                $over_all_avg_rting_perc = $avg_rate['percentage'];
            }
            ?>
            <div class="fds-dashboard-reviews-wrap">
                <?php
                if ($over_all_avg_rting > 0) {
                    ?>
                    <div class="fds-dashboard-reviews-top">
                        <span class="fds-dashboard-reviews-point"><?php echo ($over_all_avg_rting); ?></span>
                        <div class="fds-rating-stars">
                            <span class="fds-rating-stars-fill" style="width: <?php echo($over_all_avg_rting_perc) ?>%;"></span>
                        </div>
                        <span class="fds-dashboard-reviews-number"><?php printf(esc_html__("%s reviews", "wp-foodsearch"), count($all_comments)) ?></span>
                    </div>
                    <?php
                }
                ?>
                <div class="fds-dashboard-reviews-list">
                    <ul class="fds-options-wrap">
                        <?php
                        foreach ($all_comments as $r_comment) {
                            //
                            $this->reviews_list_item($r_comment, $restaurant_id);
                        }
                        ?>
                    </ul>
                </div>
            </div>
            <?php
            add_action('wp_footer', function() {
                ?>
                <div id="order-review-popup" class="fds-modal-popup fds-popup-hide fds-order-review-popup">
                    <div class="fds-modal-container">
                        <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                        <div class="fds-modal-inner-area">
                            <div class="fds-modal-content-area">
                                <div class="fds-dynm-modal-content">
                                    <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }, 20);
            wp_enqueue_style('foodsearch-reviews-barrating');
            wp_enqueue_script('foodsearch-reviews');
        } else {
            ?>
            <div class="foodsearch-noitm-found">
                <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                <p><?php esc_html_e("no reviews found.", "wp-foodsearch") ?></p>
            </div>
            <?php
        }
    }
    
    public function single_restaurant_reviews_list($html, $restaurant_id) {
        
        global $foodsearch_plugin_settings;
        
        $reviews_switch = isset($foodsearch_plugin_settings['review_settings']['enable_reviews']) ? $foodsearch_plugin_settings['review_settings']['enable_reviews'] : '';
        
        if ($reviews_switch == 'on') {
            ob_start();
            ?>
            <div class="tab-pane" id="tabref-reviews">
                <?php
                $this->restaurant_reviews_list($restaurant_id);
                ?>
            </div>
            <?php
            $html .= ob_get_clean();
        }
        
        return $html;
    }
    
    private function comment_reply_html($r_comment, $restaurant_id) {
        $com_id = $r_comment->comment_ID;
        $comment_date = strtotime($r_comment->comment_date);
        
        $user_id = $r_comment->user_id;
        
        $logo_url = foodsearch_restaurant_logo_url($user_id, $restaurant_id);
        ?>
        <li class="selected-review-item fds-list-item">
            <div class="fds-dashboard-reviews-list-inner">
                <div class="fds-item-thumb"><a href="<?php echo get_permalink($restaurant_id) ?>" class="fds-link"><img src="<?php echo ($logo_url) ?>" alt=""></a></div>
                <div class="fds-dashboard-reviews-text">
                    <span class="fds-dashboard-reviews-text-title"><?php echo get_the_title($restaurant_id) ?></span>
                    <small><?php echo (foodsearch_time_elapsed_string($comment_date)) ?></small>

                    <p><?php echo ($r_comment->comment_content) ?></p>
                </div>
            </div>
        </li>
        <?php
    }

}

new User_Reviews;
