<?php

namespace FoodSearch\Emails\User;

use FoodSearch\Emails;
use FoodSearch\Common_Functions;

class Forgot_Password extends Emails {

    public $id;
    public $name;
    public $description;
    public $group;
    public $template_codes;
    public $recipients;
    public $subject;
    public $content;
    //
    public $user_obj;
    public $pass_key;

    public function __construct() {
        add_action('init', array($this, 'init'),50);

        add_action('foodsearch_notify_to_user_forgot_password', array($this, 'send_email'), 10, 2);
    }

    public function init() {
        $this->id = 'to_user_forgot_password';
        $this->name = esc_html__('forgot password link', 'wp-foodsearch');
        $this->description = esc_html__('email will generate and send to user after submitting forgot password form.', 'wp-foodsearch');
        $this->group = 'user';
        $this->template_codes = array(
            array(
                'var' => '{first_name}',
                'display_text' => esc_html__('first name', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_first_name'),
            ),
            array(
                'var' => '{last_name}',
                'display_text' => esc_html__('last name', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_last_name'),
            ),
            array(
                'var' => '{user_email}',
                'display_text' => esc_html__('user email', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_user_email'),
            ),
            array(
                'var' => '{reset_link}',
                'display_text' => esc_html__('password reset link', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_reset_link'),
            ),
        );
        
        $this->subject = esc_html__('password reset request for ({SITE_NAME})', 'wp-foodsearch');
        
        ob_start();
        foodsearch_get_template_part('html', 'forgot-password', 'emails');
        $this->content = ob_get_clean();
    }

    public function get_email_type() {
        return 'html';
    }

    public function get_content_type() {
        switch ($this->get_email_type()) {
            case 'html':
                $content_type = 'text/html';
                break;
            case 'multipart':
                $content_type = 'multipart/alternative';
                break;
            default:
                $content_type = 'text/plain';
                break;
        }

        return apply_filters('foodsearch_email_content_type', $content_type, $this);
    }

    public function get_headers() {
        $header = 'Content-Type: ' . $this->get_content_type() . "\r\n";

        if ($this->get_from_address() && $this->get_from_name()) {
            $header .= 'Reply-to: ' . $this->get_from_name() . ' <' . $this->get_from_address() . ">\r\n";
        }

        return apply_filters('foodsearch_email_headers', $header, $this);
    }

    public function send_email($user_obj, $pass_key) {
        global $foodsearch_plugin_settings;

        $this->user_obj = $user_obj;
        $this->pass_key = $pass_key;

        $emial_switch = isset($foodsearch_plugin_settings['user_email_setins']['forgot_passwrod']) ? $foodsearch_plugin_settings['user_email_setins']['forgot_passwrod'] : '';

        if ($emial_switch == 'on') {

            $to = isset($user_obj->user_email) ? $user_obj->user_email : '';
            $subject = $this->subject;
            
            $codes = $this->template_codes;
            $email_template = $this->content;
            
            $subject = $this->replace_variables($subject, $codes);

            $message = $this->replace_variables($email_template, $codes);
            
            $headers = $this->get_headers();
            $attachments = '';

            $send_mail = $this->send($to, $subject, $message, $headers, $attachments, $this);
        }
    }

    public function get_first_name() {
        $user_obj = $this->user_obj;

        $ret_value = '-';
        
        if (isset($user_obj->first_name) && $user_obj->first_name != '') {
            $ret_value = $user_obj->first_name;
        }

        return $ret_value;
    }

    public function get_larst_name() {
        $user_obj = $this->user_obj;

        $ret_value = '-';
        
        if (isset($user_obj->last_name) && $user_obj->last_name != '') {
            $ret_value = $user_obj->last_name;
        }

        return $ret_value;
    }

    public function get_user_email() {
        $user_obj = $this->user_obj;

        $ret_value = '-';
        
        if (isset($user_obj->user_email) && $user_obj->user_email != '') {
            $ret_value = $user_obj->user_email;
        }

        return $ret_value;
    }

    public function get_reset_link() {
        $pass_key = $this->pass_key;
        $user_obj = $this->user_obj;

        $ret_value = '-';
        
        if ($pass_key != '') {
            global $foodsearch_plugin_settings;
            $dashboard_page = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
            $dashboard_page_id = $dashboard_page != '' ? foodsearch__get_post_id($dashboard_page) : '';
            $dashboard_page_url = get_permalink($dashboard_page_id);
            
            $user_id = isset($user_obj->ID) ? $user_obj->ID : '';
            $ret_value = add_query_arg(array('tab_action' => 'reset-password-request', 'key' => $pass_key, 'user_id' => $user_id), $dashboard_page_url);
        }

        return $ret_value;
    }

}

new Forgot_Password;
