const { registerBlockType } = wp.blocks;
const { RichText, InspectorControls, BlockControls, AlignmentToolbar, BlockAlignmentToolbar, PanelColorSettings } = wp.blockEditor;
const { ToggleControl, PanelBody, PanelRow, CheckboxControl, SelectControl, ColorPicker, DateTimePicker, RadioControl, RangeControl, Toolbar, ToolbarGroup, ToolbarButton, TextControl  } = wp.components;
const { __ } = wp.i18n;
const { ServerSideRender } = wp.editor;

import { paragraph, formatBold, formatItalic, link } from '@wordpress/icons';

import { select, withSelect, useSelect  } from '@wordpress/data';

import { Button, ButtonGroup } from '@wordpress/components';
import React, { useState } from "react";


registerBlockType('foodsearch/restaurant-search', {
    title: 'Restaurant Search',
    edit: (props) => {
        const { attributes, setAttributes } = props;
        const { res_cat } = useSelect ( ( select ) => {
            return {
                res_cat: select('core').getEntityRecords('taxonomy', 'restaurant_cat', {'per_page':-1, 'hide_empty': true, 'name__like': 'Burgers' })
            };
        } );

        function blockPaddingTop (newval){
            if ( isActive ) {
                setAttributes( {blockPaddingTop:newval} )
                setAttributes( {blockPaddingRight:newval} )
                setAttributes( {blockPaddingBottom:newval} )
                setAttributes( {blockPaddingLeft:newval} )
            }
            else setAttributes( {blockPaddingTop:newval} )
        }
        function blockPaddingRight (newval){
            if ( isActive ) {
                setAttributes( {blockPaddingTop:newval} )
                setAttributes( {blockPaddingRight:newval} )
                setAttributes( {blockPaddingBottom:newval} )
                setAttributes( {blockPaddingLeft:newval} )
            }
            else setAttributes( {blockPaddingRight:newval} )
        }
        function blockPaddingBottom (newval){
            if ( isActive ) {
                setAttributes( {blockPaddingTop:newval} )
                setAttributes( {blockPaddingRight:newval} )
                setAttributes( {blockPaddingBottom:newval} )
                setAttributes( {blockPaddingLeft:newval} )
            }
            else setAttributes( {blockPaddingBottom:newval} )
        }
        function blockPaddingLeft (newval){
            if ( isActive ) {
                setAttributes( {blockPaddingTop:newval} )
                setAttributes( {blockPaddingRight:newval} )
                setAttributes( {blockPaddingBottom:newval} )
                setAttributes( {blockPaddingLeft:newval} )
            }
            else setAttributes( {blockPaddingLeft:newval} )
        }

        const [isActive, setActive] = useState("false");
        const ToggleClass = () => {
            setActive(!isActive)
            setAttributes( {blockPaddingTop:9} )
            console.log( attributes.blockPaddingTop )
        };

		var options = [];
		if( res_cat && res_cat.length > 0 ) {
			options.push( { value: 0, label: 'Select/Type Cuisine' } );
			res_cat.forEach((cat) => {
				options.push({value:cat.id, label:cat.name});
			});
		} else {
			options.push( { value: 0, label: 'Loading...' } )
		}


const { color, onChange } = attributes;

        return (
            <div className="test-editor" style={{ backgroundColor: attributes.backgroundColor }} >
                <input type="text" placeholder="Select Your Area"></input>
                <SelectControl
                    label="Choose Cuisine"
                    value={ attributes.choose_cuisine }
                    options= { options }
                    id = "rest-cat"
                    onChange={ ( newval ) => setAttributes( {choose_cuisine:newval} ) }
                />

                <InspectorControls>
                    <PanelBody
                        title="Color Tab"
                        initialOpen={true}
                    >

                        <PanelRow>
                            <ColorPicker 
                                color='#000'
                                onChangeComplete={ ( color ) => onChange( color.hex ) }
                            />
                            
                        </PanelRow>
                        <PanelRow>
                            <input type="text" id="testColor" value={ attributes.txt } />
                            <RangeControl
                                label="Padding Top"
                                value={ attributes.blockPaddingTop }
                                onChange={ blockPaddingTop }
                                min={ 0 }
                                max={ 100 }
                            />
                        </PanelRow>
                        <PanelRow>
                            <RangeControl
                                label="Padding Right"
                                value={ attributes.blockPaddingRight }
                                onChange={ blockPaddingRight }
                                min={ 0 }
                                max={ 100 }
                            />
                        </PanelRow>
                        <PanelRow>
                            <RangeControl
                                label="Padding Bottom"
                                value={ attributes.blockPaddingBottom }
                                onChange={ blockPaddingBottom }
                                min={ 0 }
                                max={ 100 }
                            />
                        </PanelRow>
                        <PanelRow>
                            <RangeControl
                                label="Padding Left"
                                value={ attributes.blockPaddingLeft }
                                onChange={ blockPaddingLeft }
                                min={ 0 }
                                max={ 100 }
                            />
                        </PanelRow>
                        <PanelRow>
                            <ButtonGroup>
                                <Button variant="primary" icon={isActive ? "dashicons dashicons-lock" : "dashicons dashicons-visibility"} onClick={ToggleClass}></Button>
                            </ButtonGroup>
                        </PanelRow>

                        <PanelColorSettings
                            title={__('Background Color Settings')}
                            initialOpen={true}
                            colorSettings={[
                                {
                                    value: props.attributes.backgroundColor,
                                    onChange: (color) => props.setAttributes({ backgroundColor: color }),
                                    label: __('Background Color'),
                                    clearable: true,
                                },
                            ]}
                        />
                        <PanelColorSettings
                            colorSettings={[
                                {
                                    value: props.attributes.textColor,
                                    onChange: (color) => props.setAttributes({ textColor: color }),
                                    label: __('Text Color'),
                                    colors: []
                                }
                            ]}
                        />

                    </PanelBody>
                </InspectorControls>

            </div>

        );
    },
    save: (props) => {
        return null;
    }

});