<?php

use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

/**
 * @Manage Columns
 * @return
 *
 */
class foodsearch_post_type_customers {

    // The Constructor
    public function __construct() {
        // Adding columns
        add_action('init', [$this, 'foodsearch_customer_register'],20);
        add_action('add_meta_boxes', [$this, 'register_customer_meta_box']);
        add_action('add_meta_boxes', [$this, 'attach_author_box']);
        add_action('save_post', [$this, 'save_customer_meta_filed'], 10, 3);
        
        add_filter('manage_customers_posts_columns', array($this, 'post_columns_add'));
        add_action('manage_customers_posts_custom_column', array($this, 'post_columns'), 10, 2);
    }
    
    public function attach_author_box() {
        add_meta_box(
                'fds-attach-author', esc_html__('attached author', 'wp-foodsearch'), [$this, 'attach_author_callback'], 'customers', // $page
                'normal', // $context
                'low' // $priority
        );
    }
    
    public function attach_author_callback() {
        global $post;
        
        $selected_author = $post->post_author;
        
        $author_user = get_user_by('id', $selected_author);
        ?>
        <div class="fds-attached-author">
            <h3><?php esc_html_e('author info', 'wp-foodsearch'); ?></h3>
            <div class="attach-author-infoitm">
                <span><?php esc_html_e('author ID', 'wp-foodsearch'); ?>:</span> &nbsp; <span><?php echo ($author_user->ID) ?></span>
            </div>
            <div class="attach-author-infoitm">
                <span><?php esc_html_e('author name', 'wp-foodsearch'); ?>:</span> &nbsp; <span><?php echo ($author_user->display_name) ?></span> <a hre
            </div>
            <div class="attach-author-infoitm">
                <span><?php esc_html_e('author email', 'wp-foodsearch'); ?>:</span> &nbsp; <span><?php echo ($author_user->user_email) ?></span> <a href="<?php echo admin_url('user-edit.php?user_id=' . $author_user->ID) ?>" target="_blank"><?php esc_html_e('edit', 'wp-foodsearch'); ?></a>
            </div>
        </div>
        <br><br>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('change author', 'wp-foodsearch'); ?></label></div>
            <div class="fds-select-field">
                <select name="fds_post_selected_user" data-placeholder="<?php esc_html_e('select user', 'wp-foodsearch') ?>" class="fds-user-select2"></select>
            </div>
        </div>
        <?php
    }

    public function foodsearch_customer_register() {

        $foodsearch__options = get_option('foodsearch_plugin_options');

        $customer_slug = isset($foodsearch__options['customer_rewrite_slug']) && $foodsearch__options['customer_rewrite_slug'] != '' ? $foodsearch__options['customer_rewrite_slug'] : 'customers';

        $labels = array(
            'name' => _x('Customers', 'customers post type general name', 'wp-foodsearch'),
            'singular_name' => _x('Customer', 'post type singular name', 'wp-foodsearch'),
            'menu_name' => _x('Customers', 'admin menu', 'wp-foodsearch'),
            'name_admin_bar' => _x('Customer', 'add new on admin bar', 'wp-foodsearch'),
            'add_new' => _x('Add New', 'customers', 'wp-foodsearch'),
            'add_new_item' => esc_html__('Add New Customer', 'wp-foodsearch'),
            'new_item' => esc_html__('New Customer', 'wp-foodsearch'),
            'edit_item' => esc_html__('Edit Customer', 'wp-foodsearch'),
            'view_item' => esc_html__('View Customer', 'wp-foodsearch'),
            'all_items' => esc_html__('All Customers ', 'wp-foodsearch'),
            'search_items' => esc_html__('Search Customers', 'wp-foodsearch'),
            'parent_item_colon' => esc_html__('Parent Customers:', 'wp-foodsearch'),
            'not_found' => esc_html__('No Customers Found.', 'wp-foodsearch'),
            'not_found_in_trash' => esc_html__('No Customers Found In Trash.', 'wp-foodsearch')
        );

        $args = array(
            'labels' => $labels,
            'description' => esc_html__('description.', 'wp-foodsearch'),
            'public' => false,
            'publicly_queryable' => false,
            'show_ui' => true,
            'show_in_menu' => true,
            'query_var' => true,
            'capability_type' => 'post',
            'has_archive' => false,
            'exclude_from_search' => true,
            'hierarchical' => false,
            'show_in_rest' => true,
            'supports' => array('title')
        );
        $args = apply_filters('foodsearch_reg_post_type_customer_args', $args);

        register_post_type('customers', $args);
    }

    public function register_customer_meta_box() {
        add_meta_box(
                'customer_meta_filed', esc_html__('customer details', 'wp-foodsearch'), [$this, 'customer_filed_callback'], 'customers', // $page
                'normal', // $context
                'high'                     // $priority
        );
    }

    public function customer_filed_callback() {
        global $post;
        
        $common_functions = new Common_Functions;

        // Use nonce for verification to secure data sending
        $customer_email = get_post_meta($post->ID, 'foodsearch_email_address', true);
        $customer_phone_no = get_post_meta($post->ID, 'foodsearch_contact_number', true);
        ?>

        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('customer email', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_email_address" value="<?php echo $customer_email ?>" class="post-filed fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('customer contact no', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_contact_number" value="<?php echo $customer_phone_no ?>" class="post-filed fds-input-style">
        </div>

        <div class="filed-group">
            <?php
            $customer_id = $post->ID;
            $customer_user_id = Common_Functions::customer_user_id($customer_id);
            $user_locations = new User_Locations;
            $loc_atts = array(
                'place' => 'post_type'
            );
            $user_locations->add_locations($customer_user_id, $customer_id, $loc_atts);
            ?>
        </div>
        <?php
    }

    public function save_customer_meta_filed($post_id, $post) {
        if ($post->post_type != 'customers') {
            return false;
        }
        
        global $table_prefix, $wpdb;

        foreach ($_POST as $post_key => $post_value) {
            $post_value = foodsearch_esc_html($post_value);
            if (strstr($post_key, 'fds_setting_')) {
                $meta_key = str_replace('fds_setting_', 'foodsearch_', $post_key);
                update_post_meta($post_id, $meta_key, $post_value);
            }
        }
        
        // attach author
        if (isset($_POST['fds_post_selected_user']) && $_POST['fds_post_selected_user'] > 0) {
            $attch_user_id = $_POST['fds_post_selected_user'];
            update_user_meta($attch_user_id, 'foodsearch_user_type', 'customer');
            
            $table_name = $table_prefix . 'posts';
            $data = array('post_author' => $attch_user_id);
            $where = array('id' => $post_id);
            $wpdb->update($table_name, $data, $where);
        }
    }
    
    public function post_columns_add($columns) {

        unset($columns['date']);
        $columns['user_email'] = esc_html__('user email', 'wp-foodsearch');
        $columns['date'] = esc_html__('date', 'wp-foodsearch');
        if (class_exists('w357LoginAsUser')) {
            $columns['user_loggin_as'] = esc_html__('login as user', 'wp-foodsearch');
        }

        return $columns;
    }

    public function post_columns($column, $_post_id) {
        
        $post_obj = get_post($_post_id);
        $post_author_user = isset($post_obj->post_author) ? $post_obj->post_author : '';
        $user_obj = get_user_by('ID', $post_author_user);
        
        switch ($column) {
            case 'user_loggin_as' :
                if (class_exists('w357LoginAsUser')) {
                    $w357LoginAsUser = new w357LoginAsUser;
                    
                    if (isset($user_obj->ID)) {
                        $user_id = $user_obj->ID;
                        $the_user_obj = new WP_User($user_id);
                        $login_as_user_url = $w357LoginAsUser->build_the_login_as_user_url($the_user_obj);
                        $login_as_link = '<a class="button w357-login-as-user-btn" href="' . esc_url($login_as_user_url) . '" title="'.esc_html__('login as', 'login-as-user').': ' . $w357LoginAsUser->login_as_type($the_user_obj, false) . '"><span class="dashicons dashicons-admin-users"></span> '.esc_html__('login as', 'login-as-user').': <strong>' . $w357LoginAsUser->login_as_type($the_user_obj) . '</strong></a>';
                        echo ($login_as_link);
                    }
                }
                break;
            
            case 'user_email' :
                echo (isset($user_obj->user_email) ? '<a href="' . admin_url('user-edit.php?user_id=' . $user_obj->ID) . '" target="_blank">' . $user_obj->user_email . '</a>' : '-');
                break;
        }
    }

}

new foodsearch_post_type_customers();
